@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef MAINWINDOW_H
@@ -34,6 +34,7 @@ namespace KChart {
 
 QT_BEGIN_NAMESPACE
 class QLabel;
+class QPrinter;
 QT_END_NAMESPACE
 
 class MainWindow : public QWidget, private Ui::MainWindow
@@ -41,13 +42,13 @@ class MainWindow : public QWidget, private Ui::MainWindow
     Q_OBJECT
 
 public:
-    MainWindow( QWidget* parent = 0 );
+    MainWindow( QWidget* parent = nullptr );
 
     protected:
     /**
      * Adjusts the two small charts when the window is resized.
      */
-    /* reimp */ void resizeEvent ( QResizeEvent * ) Q_DECL_OVERRIDE;
+    /* reimp */ void resizeEvent ( QResizeEvent * ) override;
 
 private slots:
 
@@ -65,7 +66,8 @@ private slots:
     void on_vSBar_valueChanged( int value );
     void on_savePB_clicked();
     void on_savePDF_clicked();
-
+    void slotPaintRequested(QPrinter *printer);
+    void on_printButton_clicked();
 private:
     void paintMarkers( bool checked, const QSize& printSize );
 
