@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "mainwindow.h"
@@ -51,12 +51,13 @@
 #include <KGanttStyleOptionGanttItem>
 #include <KGanttConstraintModel>
 #include <KGanttGraphicsView>
+#include <KGanttDateTimeTimeLine>
 
 class ItemTypeComboBox : public QComboBox {
     Q_OBJECT
     Q_PROPERTY( KGantt::ItemType itemType READ itemType WRITE setItemType )
 public:
-    explicit ItemTypeComboBox( QWidget* parent=0 );
+    explicit ItemTypeComboBox( QWidget* parent = nullptr );
 
     KGantt::ItemType itemType() const;
 public slots:
@@ -83,17 +84,17 @@ void ItemTypeComboBox::setItemType( KGantt::ItemType typ )
 
 class MyItemDelegate : public KGantt::ItemDelegate {
 public:
-    explicit MyItemDelegate( QObject* parent=0 );
+    explicit MyItemDelegate( QObject* parent = nullptr );
 
     /*reimp*/ QWidget* createEditor( QWidget* parent,
                                      const QStyleOptionViewItem& option,
-                                     const QModelIndex& idx ) const Q_DECL_OVERRIDE;
-    /*reimp*/ void setEditorData( QWidget* editor, const QModelIndex& index ) const Q_DECL_OVERRIDE;
+                                     const QModelIndex& idx ) const override;
+    /*reimp*/ void setEditorData( QWidget* editor, const QModelIndex& index ) const override;
     /*reimp*/ void setModelData( QWidget* editor, QAbstractItemModel* model,
-                                  const QModelIndex & index ) const Q_DECL_OVERRIDE;
+                                  const QModelIndex & index ) const override;
 protected:
     /*reimp*/void drawDisplay( QPainter* painter, const QStyleOptionViewItem & option,
-                               const QRect& rect, const QString& text ) const Q_DECL_OVERRIDE;
+                               const QRect& rect, const QString& text ) const override;
 };
 
 MyItemDelegate::MyItemDelegate( QObject* parent )
@@ -154,7 +155,7 @@ void MyItemDelegate::drawDisplay( QPainter* painter, const QStyleOptionViewItem&
 class DateTimeGrid : public KGantt::DateTimeGrid
 {
 public:
-    DateTimeGrid(QObject* parent=0) {
+    DateTimeGrid(QObject* parent = nullptr) {
         setParent(parent);
         setFreeDays( QSet<Qt::DayOfWeek>() );
         setFreeDaysBrush( QBrush( Qt::NoBrush ) );
@@ -162,8 +163,8 @@ public:
     ~DateTimeGrid() { }
 
     //virtual void paintUserDefinedHeader(QPainter* painter, const QRectF& headerRect, const QRectF& exposedRect, qreal offset, const KGantt::DateTimeScaleFormatter* formatter, QWidget* widget = 0);
-    void drawBackground(QPainter* painter, const QRectF& rect) Q_DECL_OVERRIDE;
-    void drawForeground(QPainter* painter, const QRectF& rect) Q_DECL_OVERRIDE;
+    void drawBackground(QPainter* painter, const QRectF& rect) override;
+    void drawForeground(QPainter* painter, const QRectF& rect) override;
 };
 
 void DateTimeGrid::drawBackground(QPainter* painter, const QRectF& rect)
@@ -189,6 +190,7 @@ void DateTimeGrid::drawBackground(QPainter* painter, const QRectF& rect)
                            QDateTime::currentDateTime().addDays(2),
                            rect);
     painter->fillRect(r, brush);
+    KGantt::DateTimeGrid::drawBackground(painter, rect);
 }
 
 void DateTimeGrid::drawForeground(QPainter* painter, const QRectF& rect)
@@ -204,7 +206,7 @@ void DateTimeGrid::drawForeground(QPainter* painter, const QRectF& rect)
     font.setPixelSize(r.width()/5);
 
     QFontMetrics fm(font);
-    int width = fm.width(text);
+    int width = fm.boundingRect(text).width();
     int height = fm.boundingRect(text).height();
 
     painter->translate(r.center());
@@ -213,6 +215,7 @@ void DateTimeGrid::drawForeground(QPainter* painter, const QRectF& rect)
     painter->drawText(0, 0, text);
 
     painter->restore();
+    KGantt::DateTimeGrid::drawForeground(painter, rect);
 }
 /*
 void DateTimeGrid::paintUserDefinedHeader( QPainter* painter, const QRectF& headerRect, const QRectF& exposedRect, qreal offset, const KGantt::DateTimeScaleFormatter* formatter, QWidget* widget)
@@ -257,7 +260,11 @@ MainWindow::MainWindow( QWidget* parent )
     m_view->leftView()->setHorizontalScrollBarPolicy( Qt::ScrollBarAsNeeded );
     m_view->graphicsView()->setHorizontalScrollBarPolicy( Qt::ScrollBarAsNeeded );
 
-    m_view->setGrid(new DateTimeGrid(this));
+    DateTimeGrid *grid = new DateTimeGrid(this);
+    grid->timeLine()->setPen(QPen(Qt::red));
+    grid->timeLine()->setOptions(KGantt::DateTimeTimeLine::UseCustomPen);
+    grid->timeLine()->setInterval(5000);
+    m_view->setGrid(grid);
 
     //QItemEditorCreatorBase *creator = new QItemEditorCreator<ItemTypeComboBox>("itemType");
     //QItemEditorFactory* factory = new QItemEditorFactory;
@@ -271,28 +278,28 @@ MainWindow::MainWindow( QWidget* parent )
     QMenu* fileMenu = new QMenu( tr( "&File" ) );
 
 #ifndef QT_NO_PRINTER
-    fileMenu->addAction( tr( "&Save as PDF..." ), this, SLOT( slotFileSavePdf() ) );
-    fileMenu->addAction( tr( "&Print..." ), this, SLOT( slotFilePrint() ) );
+    fileMenu->addAction( tr( "&Save as PDF..." ), this, SLOT(slotFileSavePdf()) );
+    fileMenu->addAction( tr( "&Print..." ), this, SLOT(slotFilePrint()) );
 #endif
 
     fileMenu->addSeparator();
-    fileMenu->addAction( tr( "&Quit" ), this, SLOT( slotFileQuit() ) );
+    fileMenu->addAction( tr( "&Quit" ), this, SLOT(slotFileQuit()) );
 
     mb->addMenu( fileMenu );
 
     QMenu* toolsMenu = new QMenu( tr( "&Tools" ) );
 
-    toolsMenu->addAction( tr( "&New Item" ), this, SLOT( slotToolsNewItem() ) );
-    toolsMenu->addAction( tr( "&Add Item" ), this, SLOT( slotToolsAppendItem() ) );
+    toolsMenu->addAction( tr( "&New Item" ), this, SLOT(slotToolsNewItem()) );
+    toolsMenu->addAction( tr( "&Add Item" ), this, SLOT(slotToolsAppendItem()) );
     toolsMenu->addSeparator();
     QMenu *alignMenu = toolsMenu->addMenu( tr( "Ali&gn" ) );
-    alignMenu->addAction( tr( "&Left" ), this, SLOT( slotAlignLeft() ) );
-    alignMenu->addAction( tr( "&Center" ), this, SLOT( slotAlignCenter() ) );
-    alignMenu->addAction( tr( "&Right" ), this, SLOT( slotAlignRight() ) );
-    alignMenu->addAction( tr( "&Hidden" ), this, SLOT( slotAlignHidden() ) );
+    alignMenu->addAction( tr( "&Left" ), this, SLOT(slotAlignLeft()) );
+    alignMenu->addAction( tr( "&Center" ), this, SLOT(slotAlignCenter()) );
+    alignMenu->addAction( tr( "&Right" ), this, SLOT(slotAlignRight()) );
+    alignMenu->addAction( tr( "&Hidden" ), this, SLOT(slotAlignHidden()) );
     toolsMenu->addSeparator();
-    toolsMenu->addAction( tr( "&Collapse All" ), this, SLOT( slotCollapseAll() ) );
-    toolsMenu->addAction( tr( "&Expand All" ), this, SLOT( slotExpandAll() ) );
+    toolsMenu->addAction( tr( "&Collapse All" ), this, SLOT(slotCollapseAll()) );
+    toolsMenu->addAction( tr( "&Expand All" ), this, SLOT(slotExpandAll()) );
 
     mb->addMenu( toolsMenu );
 
@@ -301,8 +308,8 @@ MainWindow::MainWindow( QWidget* parent )
     slotToolsNewItem();
     slotToolsNewItem();
     for (int i = 0; i < 3; ++i) {
-        m_model->setData(m_model->index(i,2,QModelIndex()), qVariantFromValue(QDateTime::currentDateTime().addDays(i)), KGantt::StartTimeRole);
-        m_model->setData(m_model->index(i,3,QModelIndex()), qVariantFromValue(QDateTime::currentDateTime().addDays(i+1)), KGantt::EndTimeRole);
+        m_model->setData(m_model->index(i,2,QModelIndex()), QVariant::fromValue(QDateTime::currentDateTime().addDays(i)), KGantt::StartTimeRole);
+        m_model->setData(m_model->index(i,3,QModelIndex()), QVariant::fromValue(QDateTime::currentDateTime().addDays(i+1)), KGantt::EndTimeRole);
     }
     m_view->setConstraintModel(new KGantt::ConstraintModel(m_view));
     m_view->constraintModel()->addConstraint(KGantt::Constraint(m_model->index(0,0,QModelIndex()),m_model->index(1,0,QModelIndex())));
