@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef MAINWINDOW_H
@@ -33,10 +33,10 @@ class MainWindow : public QWidget, private Ui::MainWindow
     Q_OBJECT
 
 public:
-    MainWindow( QWidget* parent = 0 );
+    MainWindow( QWidget* parent = nullptr );
 
 private:
-    bool eventFilter(QObject* target, QEvent* event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject* target, QEvent* event) override;
 
 private slots:
 
