@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef MODEL_H
@@ -38,13 +38,13 @@ public:
     };
     Model();
 
-    int columnCount( const QModelIndex& parent ) const Q_DECL_OVERRIDE;
-    int rowCount( const QModelIndex& parent ) const Q_DECL_OVERRIDE;
+    int columnCount( const QModelIndex& parent ) const override;
+    int rowCount( const QModelIndex& parent ) const override;
 
-    QModelIndex index( int row, int column, const QModelIndex& parent ) const Q_DECL_OVERRIDE;
-    QModelIndex parent( const QModelIndex& index ) const Q_DECL_OVERRIDE;
+    QModelIndex index( int row, int column, const QModelIndex& parent ) const override;
+    QModelIndex parent( const QModelIndex& index ) const override;
 
-    QVariant data( const QModelIndex& index, int role ) const Q_DECL_OVERRIDE;
+    QVariant data( const QModelIndex& index, int role ) const override;
 
     void setFunction( Function f );
 
