@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef AXISSETTINGS_H
@@ -32,7 +32,7 @@ class AxisSettings : public QWidget
     Q_OBJECT
 
 public:
-    explicit AxisSettings( KChart::Chart *chart, QWidget *parent = 0 );
+    explicit AxisSettings( KChart::Chart *chart, QWidget *parent = nullptr );
     ~AxisSettings();
 
 public Q_SLOTS:
