@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef MAINWINDOW_H
@@ -39,30 +39,30 @@ class MainWindow : public QWidget, private Ui::MainWindow
     Q_OBJECT
 
 public:
-    MainWindow( QWidget* parent = 0 );
+    MainWindow( QWidget* parent = nullptr );
     void updateData(QString data);
 
     protected:
         /**
          * Adjusts the two small charts when the window is resized.
          */
-        /* reimp */ void resizeEvent ( QResizeEvent * ) Q_DECL_OVERRIDE;
+        /* reimp */ void resizeEvent ( QResizeEvent * ) override;
 
 private slots:
 
-    void on_lineTypeCB_currentIndexChanged( const QString & text );
-    void on_paintLegendCB_toggled( bool checked );
-    void on_paintValuesCB_toggled( bool checked );
-    void on_paintMarkersCB_toggled( bool checked );
-    void on_markersStyleCB_currentIndexChanged( const QString & text );
-    void on_markersWidthSB_valueChanged( int i );
-    void on_markersHeightSB_valueChanged( int i);
-    void on_displayAreasCB_toggled( bool checked );
-    void on_transparencySB_valueChanged( int i );
-    void on_zoomFactorSB_valueChanged( qreal factor );
-    void on_hSBar_valueChanged( int value );
-    void on_vSBar_valueChanged( int value );
-    void on_savePB_clicked();
+    void setLineType( const QString & text );
+    void setLegendVisible( bool visible );
+    void setValuesVisible( bool visible );
+    void setMarkersVisible( bool visible );
+    void updateMarkers();
+    void updateMarkersHeight();
+    void updateMarkersWidth();
+    void updateAreas( bool visible );
+    void updateAreasTransparency();
+    void setZoomFactor( qreal factor );
+    void setHPos( int value );
+    void setVPos( int value );
+    void saveChart();
 
 private:
     void paintMarkers( bool checked, const QSize& printSize );
