@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef SUMGUI_MODELPARAMVSPARAM_H
@@ -31,7 +31,7 @@ class ModelParamVsParam: public QStandardItemModel
 
 public:
 	ModelParamVsParam(
-		QObject					*p_parent = 0);
+		QObject					*p_parent = nullptr);
 
 	void setTimeout(
 		int					p_timeout);
