@@ -14,11 +14,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "mainwindow.h"
-
+#include <QElapsedTimer>
 #include <QtTest/QtTest>
 
 class TestParamVsParam: public QObject {
@@ -27,17 +27,17 @@ private slots:
 
   void testMainWindow()
   {
-    QTime t;
+    QElapsedTimer t;
     t.start();
 
     MainWindow      mainWindow;
 
-    qDebug("time constructor: %d ms", t.elapsed());
+    qDebug("time constructor: %lld ms", t.elapsed());
 
     mainWindow.show();
     QTimer::singleShot(0, qApp, SLOT(quit()));
 
-    qDebug("time show(): %d ms", t.elapsed());
+    qDebug("time show(): %lld ms", t.elapsed());
     // uncomment to see it blink:
     // QTest::qWait( 10000 );
 
