@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <qapplication.h>
@@ -44,7 +44,7 @@ public:
     }
 
 protected:
-    KDAB_REIMP void resizeEvent( QResizeEvent* ) Q_DECL_OVERRIDE {
+    KDAB_REIMP void resizeEvent( QResizeEvent* ) override {
         // Note that this is never called unless the widget is shown.
         qDebug() << "resizeEvent " << size();
     }
@@ -55,7 +55,7 @@ class MyWidgetItem : public QWidgetItem
 public:
     explicit MyWidgetItem(QWidget *w) : QWidgetItem(w) { }
 
-    KDAB_REIMP bool isEmpty() const Q_DECL_OVERRIDE { return false; }
+    KDAB_REIMP bool isEmpty() const override { return false; }
 };
 
 class TestQLayout : public QObject
@@ -67,7 +67,7 @@ private slots:
     // This is very much like KChart::Chart does with legends
     void testBoxLayoutHiddenWidget() {
         QBoxLayout* vLayout = new QVBoxLayout;
-        MyLegendWidget* widget1 = new MyLegendWidget( 0 );
+        MyLegendWidget* widget1 = new MyLegendWidget( nullptr );
         widget1->resize( 10, 10 );
 
         // Adding a hidden widget doesn't work, the layout ignores it
@@ -90,7 +90,7 @@ private slots:
     }
 
     void testBoxLayoutChildWidget() {
-        QWidget* topLevelWidget = new QWidget( 0 );
+        QWidget* topLevelWidget = new QWidget( nullptr );
         // This time the layout is associated with a widget, like d->layout in KChart::Chart.
         QBoxLayout* vLayout = new QVBoxLayout( topLevelWidget );
         MyLegendWidget* widget1 = new MyLegendWidget( topLevelWidget );
@@ -125,7 +125,7 @@ private slots:
     }
 
     void testSubGridLayout() {
-        QWidget* topLevelWidget = new QWidget( 0 );
+        QWidget* topLevelWidget = new QWidget( nullptr );
         QBoxLayout* vLayout = new QVBoxLayout( topLevelWidget );
         QGridLayout* gridLayout = new QGridLayout();
 
