@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartAbstractCartesianDiagram.h"
@@ -26,7 +26,7 @@
 using namespace KChart;
 
 AbstractCartesianDiagram::Private::Private()
-    : referenceDiagram( 0 )
+    : referenceDiagram( nullptr )
 {
 }
 
@@ -67,14 +67,14 @@ KChart::AbstractCartesianDiagram::~AbstractCartesianDiagram()
 void AbstractCartesianDiagram::init()
 {
     d->compressor.setModel( attributesModel() );
-    connect( this, SIGNAL( layoutChanged( AbstractDiagram* ) ),
-             &d->compressor, SLOT( slotDiagramLayoutChanged( AbstractDiagram* ) ) );
-    connect( this, SIGNAL( attributesModelAboutToChange( AttributesModel*, AttributesModel* ) ),
-             this, SLOT( connectAttributesModel( AttributesModel* ) ) );
+    connect( this, SIGNAL(layoutChanged(AbstractDiagram*)),
+             &d->compressor, SLOT(slotDiagramLayoutChanged(AbstractDiagram*)) );
+    connect( this, SIGNAL(attributesModelAboutToChange(AttributesModel*,AttributesModel*)),
+             this, SLOT(connectAttributesModel(AttributesModel*)) );
 
     if ( d->plane ) {
-        connect( d->plane, SIGNAL( viewportCoordinateSystemChanged() ),
-                                   this, SIGNAL( viewportCoordinateSystemChanged() ) );
+        connect( d->plane, SIGNAL(viewportCoordinateSystemChanged()),
+                                   this, SIGNAL(viewportCoordinateSystemChanged()) );
     }
 }
 
@@ -93,7 +93,7 @@ void AbstractCartesianDiagram::takeAxis( CartesianAxis *axis )
     if ( idx != -1 )
         d->axesList.takeAt( idx );
     axis->deleteObserver( this );
-    axis->setParentWidget( 0 );
+    axis->setParentWidget( nullptr );
     layoutPlanes();
 }
 
@@ -113,31 +113,31 @@ void KChart::AbstractCartesianDiagram::layoutPlanes()
 void KChart::AbstractCartesianDiagram::setCoordinatePlane( AbstractCoordinatePlane* plane )
 {
     if ( coordinatePlane() ) {
-        disconnect( attributesModel(), SIGNAL( rowsRemoved( const QModelIndex&, int, int ) ),
-                    coordinatePlane(), SLOT( relayout() ) );
-        disconnect( attributesModel(), SIGNAL( rowsInserted( const QModelIndex&, int, int ) ),
-                    coordinatePlane(), SLOT( relayout() ) );
-        disconnect( attributesModel(), SIGNAL( columnsRemoved( const QModelIndex&, int, int ) ),
-                    coordinatePlane(), SLOT( relayout() ) );
-        disconnect( attributesModel(), SIGNAL( columnsInserted( const QModelIndex&, int, int ) ),
-                    coordinatePlane(), SLOT( relayout() ) );
+        disconnect( attributesModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+                    coordinatePlane(), SLOT(relayout()) );
+        disconnect( attributesModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
+                    coordinatePlane(), SLOT(relayout()) );
+        disconnect( attributesModel(), SIGNAL(columnsRemoved(QModelIndex,int,int)),
+                    coordinatePlane(), SLOT(relayout()) );
+        disconnect( attributesModel(), SIGNAL(columnsInserted(QModelIndex,int,int)),
+                    coordinatePlane(), SLOT(relayout()) );
         disconnect( coordinatePlane() );
     }
 
     AbstractDiagram::setCoordinatePlane(plane);
     if ( plane ) {
         // Readjust the layout when the dataset count changes
-        connect( attributesModel(), SIGNAL( rowsRemoved( const QModelIndex&, int, int ) ),
-                 plane, SLOT( relayout() ) );
-        connect( attributesModel(), SIGNAL( rowsInserted( const QModelIndex&, int, int ) ),
-                 plane, SLOT( relayout() ) );
-        connect( attributesModel(), SIGNAL( columnsRemoved( const QModelIndex&, int, int ) ),
-                 plane, SLOT( relayout() ) );
-        connect( attributesModel(), SIGNAL( columnsInserted( const QModelIndex&, int, int ) ),
-                 plane, SLOT( relayout() ) );
-        connect( plane, SIGNAL( viewportCoordinateSystemChanged() ),
-                 this, SIGNAL( viewportCoordinateSystemChanged() ) );
-        connect( plane, SIGNAL( viewportCoordinateSystemChanged() ), this, SLOT( update() ) );
+        connect( attributesModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
+                 plane, SLOT(relayout()) );
+        connect( attributesModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
+                 plane, SLOT(relayout()) );
+        connect( attributesModel(), SIGNAL(columnsRemoved(QModelIndex,int,int)),
+                 plane, SLOT(relayout()) );
+        connect( attributesModel(), SIGNAL(columnsInserted(QModelIndex,int,int)),
+                 plane, SLOT(relayout()) );
+        connect( plane, SIGNAL(viewportCoordinateSystemChanged()),
+                 this, SIGNAL(viewportCoordinateSystemChanged()) );
+        connect( plane, SIGNAL(viewportCoordinateSystemChanged()), this, SLOT(update()) );
     }
 }
 
