@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartCartesianCoordinatePlane.h"
@@ -36,6 +36,7 @@
 #include <QtDebug>
 #include <QPainter>
 #include <QTime>
+#include <QElapsedTimer>
 
 
 using namespace KChart;
@@ -85,10 +86,10 @@ void CartesianCoordinatePlane::addDiagram( AbstractDiagram* diagram )
                 "CartesianCoordinatePlane::addDiagram", "Only cartesian "
                 "diagrams can be added to a cartesian coordinate plane!" );
     AbstractCoordinatePlane::addDiagram( diagram );
-    connect( diagram,  SIGNAL( layoutChanged ( AbstractDiagram* ) ),
-             SLOT( slotLayoutChanged( AbstractDiagram* ) ) );
+    connect( diagram,  SIGNAL(layoutChanged(AbstractDiagram*)),
+             SLOT(slotLayoutChanged(AbstractDiagram*)) );
 
-    connect( diagram, SIGNAL( propertiesChanged() ), this, SIGNAL( propertiesChanged() ) );
+    connect( diagram, SIGNAL(propertiesChanged()), this, SIGNAL(propertiesChanged()) );
 }
 
 
@@ -125,7 +126,7 @@ void CartesianCoordinatePlane::paint( QPainter* painter )
                 continue;
             }
             bool doDumpPaintTime = AbstractDiagram::Private::get( diags[ i ] )->doDumpPaintTime;
-            QTime stopWatch;
+            QElapsedTimer stopWatch;
             if ( doDumpPaintTime ) {
                 stopWatch.start();
             }
@@ -266,7 +267,7 @@ QRectF CartesianCoordinatePlane::calculateRawDataBoundingRect() const
 
 DataDimensionsList CartesianCoordinatePlane::getDataDimensionsList() const
 {
-    const AbstractCartesianDiagram* dgr = diagrams().isEmpty() ? 0 :
+    const AbstractCartesianDiagram* dgr = diagrams().isEmpty() ? nullptr :
                    qobject_cast< const AbstractCartesianDiagram* >( diagrams().first() );
     if ( dgr && dgr->referenceDiagram() ) {
         dgr = dgr->referenceDiagram();
@@ -278,7 +279,7 @@ DataDimensionsList CartesianCoordinatePlane::getDataDimensionsList() const
     // It does make sense to retrieve the orientation from the first diagram. This is because
     // a coordinate plane can either be for horizontal *or* for vertical diagrams. Both at the
     // same time won't work, and thus the orientation for all diagrams is the same as for the first one.
-    const Qt::Orientation diagramOrientation = barDiagram != 0 ? barDiagram->orientation() : Qt::Vertical;
+    const Qt::Orientation diagramOrientation = barDiagram != nullptr ? barDiagram->orientation() : Qt::Vertical;
     const bool diagramIsVertical = diagramOrientation == Qt::Vertical;
 
     DataDimensionsList l;
@@ -777,15 +778,15 @@ AbstractCoordinatePlane* CartesianCoordinatePlane::sharedAxisMasterPlane( QPaint
 {
     CartesianCoordinatePlane* plane = this;
     AbstractCartesianDiagram* diag = dynamic_cast< AbstractCartesianDiagram* >( plane->diagram() );
-    const CartesianAxis* sharedAxis = 0;
-    if ( diag != 0 )
+    const CartesianAxis* sharedAxis = nullptr;
+    if ( diag != nullptr )
     {
         const CartesianAxisList axes = diag->axes();
         Q_FOREACH( const CartesianAxis* a, axes )
         {
             CartesianCoordinatePlane* p = const_cast< CartesianCoordinatePlane* >(
                                               dynamic_cast< const CartesianCoordinatePlane* >( a->coordinatePlane() ) );
-            if ( p != 0 && p != this )
+            if ( p != nullptr && p != this )
             {
                 plane = p;
                 sharedAxis = a;
@@ -793,7 +794,7 @@ AbstractCoordinatePlane* CartesianCoordinatePlane::sharedAxisMasterPlane( QPaint
         }
     }
 
-    if ( plane == this || painter == 0 )
+    if ( plane == this || painter == nullptr )
         return plane;
 
     const QPointF zero = QPointF( 0, 0 );
