@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartLineDiagram.h"
@@ -73,9 +73,6 @@ LineDiagram::~LineDiagram()
     delete d->percentDiagram;
 }
 
-/**
-  * Creates an exact copy of this diagram.
-  */
 LineDiagram * LineDiagram::clone() const
 {
     LineDiagram* newDiagram = new LineDiagram( new Private( *d ) );
@@ -98,10 +95,6 @@ bool LineDiagram::compare( const LineDiagram* other ) const
             (reverseDatasetOrder() == other->reverseDatasetOrder());
 }
 
-/**
-  * Sets the line diagram's type to \a type
-  * \sa LineDiagram::LineType
-  */
 void LineDiagram::setType( const LineType type )
 {
     if ( d->implementor->type() == type ) return;
@@ -134,9 +127,6 @@ void LineDiagram::setType( const LineType type )
    emit propertiesChanged();
 }
 
-/**
-  * @return the type of the line diagram
-  */
 LineDiagram::LineType LineDiagram::type() const
 {
     return d->implementor->type();
@@ -172,54 +162,39 @@ bool LineDiagram::reverseDatasetOrder() const
     return d->reverseDatasetOrder;
 }
 
-/**
-  * Sets the global line attributes to \a la
-  */
 void LineDiagram::setLineAttributes( const LineAttributes& la )
 {
     d->attributesModel->setModelData(
-        qVariantFromValue( la ),
+        QVariant::fromValue( la ),
         LineAttributesRole );
     emit propertiesChanged();
 }
 
-/**
-  * Sets the line attributes of data set \a column to \a la
-  */
 void LineDiagram::setLineAttributes(
         int column,
     const LineAttributes& la )
 {
-    d->setDatasetAttrs( column, qVariantFromValue( la ), LineAttributesRole );
+    d->setDatasetAttrs( column, QVariant::fromValue( la ), LineAttributesRole );
     emit propertiesChanged();
 }
 
-/**
-  * Resets the line attributes of data set \a column
-  */
 void LineDiagram::resetLineAttributes( int column )
 {
     d->resetDatasetAttrs( column, LineAttributesRole );
     emit propertiesChanged();
 }
 
-/**
-  * Sets the line attributes for the model index \a index to \a la
-  */
 void LineDiagram::setLineAttributes(
         const QModelIndex& index,
     const LineAttributes& la )
 {
     d->attributesModel->setData(
             d->attributesModel->mapFromSource(index),
-    qVariantFromValue( la ),
+    QVariant::fromValue( la ),
     LineAttributesRole );
     emit propertiesChanged();
 }
 
-/**
- * Remove any explicit line attributes settings that might have been specified before.
- */
 void LineDiagram::resetLineAttributes( const QModelIndex & index )
 {
     d->attributesModel->resetData(
@@ -227,17 +202,11 @@ void LineDiagram::resetLineAttributes( const QModelIndex & index )
     emit propertiesChanged();
 }
 
-/**
-  * @return the global line attribute set
-  */
 LineAttributes LineDiagram::lineAttributes() const
 {
     return d->attributesModel->data( KChart::LineAttributesRole ).value<LineAttributes>();
 }
 
-/**
-  * @return the line attribute set of data set \a column
-  */
 LineAttributes LineDiagram::lineAttributes( int column ) const
 {
     const QVariant attrs( d->datasetAttrs( column, LineAttributesRole ) );
@@ -246,9 +215,6 @@ LineAttributes LineDiagram::lineAttributes( int column ) const
     return lineAttributes();
 }
 
-/**
-  * @return the line attribute set of the model index \a index
-  */
 LineAttributes LineDiagram::lineAttributes(
     const QModelIndex& index ) const
 {
@@ -257,34 +223,25 @@ LineAttributes LineDiagram::lineAttributes(
             KChart::LineAttributesRole ).value<LineAttributes>();
 }
 
-/**
-  * Sets the global 3D line attributes to \a la
-  */
 void LineDiagram::setThreeDLineAttributes(
     const ThreeDLineAttributes& la )
 {
     setDataBoundariesDirty();
     d->attributesModel->setModelData(
-        qVariantFromValue( la ),
+        QVariant::fromValue( la ),
         ThreeDLineAttributesRole );
    emit propertiesChanged();
 }
 
-/**
-  * Sets the 3D line attributes of data set \a column to \a ta
-  */
 void LineDiagram::setThreeDLineAttributes(
     int column,
     const ThreeDLineAttributes& la )
 {
     setDataBoundariesDirty();
-    d->setDatasetAttrs( column, qVariantFromValue( la ), ThreeDLineAttributesRole );
+    d->setDatasetAttrs( column, QVariant::fromValue( la ), ThreeDLineAttributesRole );
    emit propertiesChanged();
 }
 
-/**
-  * Sets the 3D line attributes of model index \a index to \a la
-  */
 void LineDiagram::setThreeDLineAttributes(
     const QModelIndex & index,
     const ThreeDLineAttributes& la )
@@ -292,22 +249,16 @@ void LineDiagram::setThreeDLineAttributes(
     setDataBoundariesDirty();
     d->attributesModel->setData(
         d->attributesModel->mapFromSource(index),
-        qVariantFromValue( la ),
+        QVariant::fromValue( la ),
         ThreeDLineAttributesRole );
    emit propertiesChanged();
 }
 
-/**
-  * @return the global 3D line attributes
-  */
 ThreeDLineAttributes LineDiagram::threeDLineAttributes() const
 {
     return d->attributesModel->data( KChart::ThreeDLineAttributesRole ).value<ThreeDLineAttributes>();
 }
 
-/**
-  * @return the 3D line attributes of data set \a column
-  */
 ThreeDLineAttributes LineDiagram::threeDLineAttributes( int column ) const
 {
     const QVariant attrs( d->datasetAttrs( column, ThreeDLineAttributesRole ) );
@@ -316,9 +267,6 @@ ThreeDLineAttributes LineDiagram::threeDLineAttributes( int column ) const
     return threeDLineAttributes();
 }
 
-/**
-  * @return the 3D line attributes of the model index \a index
-  */
 ThreeDLineAttributes LineDiagram::threeDLineAttributes( const QModelIndex& index ) const
 {
     return d->attributesModel->data(
@@ -336,21 +284,15 @@ qreal LineDiagram::threeDItemDepth( int column ) const
     return threeDLineAttributes( column ).validDepth();
 }
 
-/**
-  * Sets the value tracker attributes of the model index \a index to \a va
-  */
 void LineDiagram::setValueTrackerAttributes( const QModelIndex & index,
                                              const ValueTrackerAttributes & va )
 {
     d->attributesModel->setData( d->attributesModel->mapFromSource(index),
-                                 qVariantFromValue( va ),
+                                 QVariant::fromValue( va ),
                                  KChart::ValueTrackerAttributesRole );
     emit propertiesChanged();
 }
 
-/**
-  * Returns the value tracker attributes of the model index \a index
-  */
 ValueTrackerAttributes LineDiagram::valueTrackerAttributes(
         const QModelIndex & index ) const
 {
