@@ -14,17 +14,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef PLOTTERDIAGRAMCOMPRESSOR_H
 #define PLOTTERDIAGRAMCOMPRESSOR_H
 
-#include <QtCore/QObject>
-#include <QtCore/QAbstractItemModel>
-#include <QtCore/QPointer>
-#include <QtCore/QVector>
-#include <QtCore/QDateTime>
+#include <QObject>
+#include <QAbstractItemModel>
+#include <QPointer>
+#include <QVector>
+#include <QDateTime>
 
 #include <cmath>
 #include <limits>
@@ -120,7 +120,7 @@ public:
                    second == rhs.second;
         }
     };
-    explicit PlotterDiagramCompressor(QObject *parent = 0);
+    explicit PlotterDiagramCompressor(QObject *parent = nullptr);
     ~PlotterDiagramCompressor();
     Iterator begin( int dataSet );
     Iterator end( int dataSet );    
