@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartAbstractDiagram.h"
@@ -26,6 +26,7 @@
 #include <QApplication>
 #include <QAbstractProxyModel>
 #include <QSizeF>
+#include <QPainterPath>
 
 #include "KChartAbstractCoordinatePlane.h"
 #include "KChartChart.h"
@@ -151,19 +152,19 @@ void AbstractDiagram::setSelectionModel( QItemSelectionModel* newSelectionModel
 {
     if ( selectionModel() )
     {
-        disconnect( selectionModel(), SIGNAL( currentChanged( QModelIndex, QModelIndex ) ), this, SIGNAL( modelsChanged() ) );
-        disconnect( selectionModel(), SIGNAL( selectionChanged( QItemSelection, QItemSelection ) ), this, SIGNAL( modelsChanged() ) );
+        disconnect( selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SIGNAL(modelsChanged()) );
+        disconnect( selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SIGNAL(modelsChanged()) );
     }
     QAbstractItemView::setSelectionModel( newSelectionModel );
     if ( selectionModel() )
     {
-        connect( selectionModel(), SIGNAL( currentChanged( QModelIndex, QModelIndex ) ), this, SIGNAL( modelsChanged() ) );
-        connect( selectionModel(), SIGNAL( selectionChanged( QItemSelection, QItemSelection ) ), this, SIGNAL( modelsChanged() ) );
+        connect( selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SIGNAL(modelsChanged()) );
+        connect( selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SIGNAL(modelsChanged()) );
     }
     emit modelsChanged();
 }
 
-/*! Sets an external AttributesModel on this diagram. By default, a diagram has it's
+/* Sets an external AttributesModel on this diagram. By default, a diagram has it's
   own internal set of attributes, but an external one can be set. This can be used to
   share attributes between several diagrams. The diagram does not take ownership of the
   attributesmodel.
@@ -206,14 +207,13 @@ QModelIndex AbstractDiagram::conditionallyMapFromSource( const QModelIndex & ind
     return index.model() == attributesModel() ? index : attributesModel()->mapFromSource( index );
 }
 
-/*! \reimpl */
-void AbstractDiagram::setRootIndex ( const QModelIndex& idx )
+/* \reimpl */
+void AbstractDiagram::setRootIndex( const QModelIndex& idx )
 {
     QAbstractItemView::setRootIndex( idx );
     setAttributesModelRootIndex( d->attributesModel->mapFromSource( idx ) );
 }
 
-/*! \internal */
 void AbstractDiagram::setAttributesModelRootIndex( const QModelIndex& idx )
 {
     d->attributesModelRootIndex = idx;
@@ -221,8 +221,6 @@ void AbstractDiagram::setAttributesModelRootIndex( const QModelIndex& idx )
     scheduleDelayedItemsLayout();
 }
 
-/*! returns a QModelIndex pointing into the AttributesModel that corresponds to the
-  root index of the diagram. */
 QModelIndex AbstractDiagram::attributesModelRootIndex() const
 {
     if ( !d->attributesModelRootIndex.isValid() )
@@ -260,20 +258,20 @@ void AbstractDiagram::setHidden( const QModelIndex & index, bool hidden )
 {
     d->attributesModel->setData(
         conditionallyMapFromSource( index ),
-        qVariantFromValue( hidden ),
+        QVariant::fromValue( hidden ),
         DataHiddenRole );
     emit dataHidden();
 }
 
 void AbstractDiagram::setHidden( int dataset, bool hidden )
 {
-    d->setDatasetAttrs( dataset, qVariantFromValue( hidden ), DataHiddenRole );
+    d->setDatasetAttrs( dataset, QVariant::fromValue( hidden ), DataHiddenRole );
     emit dataHidden();
 }
 
 void AbstractDiagram::setHidden( bool hidden )
 {
-    d->attributesModel->setModelData( qVariantFromValue( hidden ), DataHiddenRole );
+    d->attributesModel->setModelData( QVariant::fromValue( hidden ), DataHiddenRole );
     emit dataHidden();
 }
 
@@ -305,7 +303,7 @@ bool AbstractDiagram::isHidden( const QModelIndex & index ) const
 void AbstractDiagram::setDataValueAttributes( const QModelIndex & index,
                                               const DataValueAttributes & a )
 {
-    d->attributesModel->setData( conditionallyMapFromSource( index ), qVariantFromValue( a ),
+    d->attributesModel->setData( conditionallyMapFromSource( index ), QVariant::fromValue( a ),
                                  DataValueLabelAttributesRole );
     emit propertiesChanged();
 }
@@ -313,7 +311,7 @@ void AbstractDiagram::setDataValueAttributes( const QModelIndex & index,
 
 void AbstractDiagram::setDataValueAttributes( int dataset, const DataValueAttributes & a )
 {
-    d->setDatasetAttrs( dataset, qVariantFromValue( a ), DataValueLabelAttributesRole );
+    d->setDatasetAttrs( dataset, QVariant::fromValue( a ), DataValueLabelAttributesRole );
     emit propertiesChanged();
 }
 
@@ -351,7 +349,7 @@ DataValueAttributes AbstractDiagram::dataValueAttributes( const QModelIndex & in
 
 void AbstractDiagram::setDataValueAttributes( const DataValueAttributes & a )
 {
-    d->attributesModel->setModelData( qVariantFromValue( a ), DataValueLabelAttributesRole );
+    d->attributesModel->setModelData( QVariant::fromValue( a ), DataValueLabelAttributesRole );
     emit propertiesChanged();
 }
 
@@ -494,7 +492,7 @@ void AbstractDiagram::paintMarker( QPainter* painter,
     const bool isFourPixels = (markerAttributes.markerStyle() == MarkerAttributes::Marker4Pixels);
     if ( isFourPixels || (markerAttributes.markerStyle() == MarkerAttributes::Marker1Pixel) ) {
         // for high-performance point charts with tiny point markers:
-        painter->setPen( PrintingParameters::scalePen( QPen( brush.color().light() ) ) );
+        painter->setPen( PrintingParameters::scalePen( QPen( brush.color().lighter() ) ) );
         if ( isFourPixels ) {
             const qreal x = pos.x();
             const qreal y = pos.y();
@@ -831,20 +829,20 @@ void AbstractDiagram::setPen( const QModelIndex& index, const QPen& pen )
 {
     attributesModel()->setData(
         conditionallyMapFromSource( index ),
-        qVariantFromValue( pen ), DatasetPenRole );
+        QVariant::fromValue( pen ), DatasetPenRole );
     emit propertiesChanged();
 }
 
 void AbstractDiagram::setPen( const QPen& pen )
 {
     attributesModel()->setModelData(
-        qVariantFromValue( pen ), DatasetPenRole );
+        QVariant::fromValue( pen ), DatasetPenRole );
     emit propertiesChanged();
 }
 
 void AbstractDiagram::setPen( int dataset, const QPen& pen )
 {
-    d->setDatasetAttrs( dataset, qVariantFromValue( pen ), DatasetPenRole );
+    d->setDatasetAttrs( dataset, QVariant::fromValue( pen ), DatasetPenRole );
     emit propertiesChanged();
 }
 
@@ -872,20 +870,20 @@ void AbstractDiagram::setBrush( const QModelIndex& index, const QBrush& brush )
 {
     attributesModel()->setData(
         conditionallyMapFromSource( index ),
-        qVariantFromValue( brush ), DatasetBrushRole );
+        QVariant::fromValue( brush ), DatasetBrushRole );
     emit propertiesChanged();
 }
 
 void AbstractDiagram::setBrush( const QBrush& brush )
 {
     attributesModel()->setModelData(
-        qVariantFromValue( brush ), DatasetBrushRole );
+        QVariant::fromValue( brush ), DatasetBrushRole );
     emit propertiesChanged();
 }
 
 void AbstractDiagram::setBrush( int dataset, const QBrush& brush )
 {
-    d->setDatasetAttrs( dataset, qVariantFromValue( brush ), DatasetBrushRole );
+    d->setDatasetAttrs( dataset, QVariant::fromValue( brush ), DatasetBrushRole );
     emit propertiesChanged();
 }
 
@@ -908,7 +906,7 @@ QBrush AbstractDiagram::brush( const QModelIndex& index ) const
         attributesModel()->data( conditionallyMapFromSource( index ), DatasetBrushRole ).value< QBrush >();
 }
 
-/**
+/*
   * Sets the unit prefix for one value
   * @param prefix the prefix to be set
   * @param column the value using that prefix
@@ -919,7 +917,7 @@ void AbstractDiagram::setUnitPrefix( const QString& prefix, int column, Qt::Orie
     d->unitPrefixMap[ column ][ orientation ]= prefix;
 }
 
-/**
+/*
   * Sets the unit prefix for all values
   * @param prefix the prefix to be set
   * @param orientation the orientantion of the axis to set
@@ -929,7 +927,7 @@ void AbstractDiagram::setUnitPrefix( const QString& prefix, Qt::Orientation orie
     d->unitPrefix[ orientation ] = prefix;
 }
 
-/**
+/*
   * Sets the unit suffix for one value
   * @param suffix the suffix to be set
   * @param column the value using that suffix
@@ -940,7 +938,7 @@ void AbstractDiagram::setUnitSuffix( const QString& suffix, int column, Qt::Orie
     d->unitSuffixMap[ column ][ orientation ]= suffix;
 }
 
-/**
+/*
   * Sets the unit suffix for all values
   * @param suffix the suffix to be set
   * @param orientation the orientantion of the axis to set
@@ -950,7 +948,7 @@ void AbstractDiagram::setUnitSuffix( const QString& suffix, Qt::Orientation orie
     d->unitSuffix[ orientation ] = suffix;
 }
 
-/**
+/*
   * Returns the unit prefix for a special value
   * @param column the value which's prefix is requested
   * @param orientation the orientation of the axis
@@ -964,7 +962,7 @@ QString AbstractDiagram::unitPrefix( int column, Qt::Orientation orientation, bo
     return d->unitPrefix[ orientation ];
 }
 
-/** Returns the global unit prefix
+/* Returns the global unit prefix
   * @param orientation the orientation of the axis
   * @return the unit prefix
   */
@@ -973,7 +971,7 @@ QString AbstractDiagram::unitPrefix( Qt::Orientation orientation ) const
     return d->unitPrefix[ orientation ];
 }
 
-/**
+/*
   * Returns the unit suffix for a special value
   * @param column the value which's suffix is requested
   * @param orientation the orientation of the axis
@@ -987,7 +985,7 @@ QString AbstractDiagram::unitSuffix( int column, Qt::Orientation orientation, bo
     return d->unitSuffix[ orientation ];
 }
 
-/** Returns the global unit suffix
+/* Returns the global unit suffix
   * @param orientation the orientation of the axis
   * @return the unit siffix
   */
