@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 //
@@ -69,10 +69,10 @@ LabelPaintInfo::LabelPaintInfo( const LabelPaintInfo& other )
 }
 
 AbstractDiagram::Private::Private()
-  : diagram( 0 )
+  : diagram( nullptr )
   , doDumpPaintTime( false )
-  , plane( 0 )
-  , attributesModel( new PrivateAttributesModel(0,0) )
+  , plane( nullptr )
+  , attributesModel( new PrivateAttributesModel(nullptr,nullptr) )
   , allowOverlappingDataValueTexts( false )
   , antiAliasing( true )
   , percent( false )
@@ -113,48 +113,48 @@ void AbstractDiagram::Private::setAttributesModel( AttributesModel* amodel )
         if ( qobject_cast< PrivateAttributesModel* >( attributesModel ) ) {
             delete attributesModel;
         } else {
-            disconnect( attributesModel, SIGNAL( rowsInserted( QModelIndex, int, int ) ),
-                        diagram, SLOT( setDataBoundariesDirty() ) );
-            disconnect( attributesModel, SIGNAL( columnsInserted( QModelIndex, int, int ) ),
-                        diagram, SLOT( setDataBoundariesDirty() ) );
-            disconnect( attributesModel, SIGNAL( rowsRemoved( QModelIndex, int, int ) ),
-                        diagram, SLOT( setDataBoundariesDirty() ) );
-            disconnect( attributesModel, SIGNAL( columnsRemoved( QModelIndex, int, int ) ),
-                        diagram, SLOT( setDataBoundariesDirty() ) );
-            disconnect( attributesModel, SIGNAL( modelReset() ),
-                        diagram, SLOT( setDataBoundariesDirty() ) );
-            disconnect( attributesModel, SIGNAL( layoutChanged() ),
-                        diagram, SLOT( setDataBoundariesDirty() ) );
-            disconnect( attributesModel, SIGNAL( dataChanged( QModelIndex, QModelIndex ) ),
-                        diagram, SIGNAL( modelDataChanged() ));
+            disconnect( attributesModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
+                        diagram, SLOT(setDataBoundariesDirty()) );
+            disconnect( attributesModel, SIGNAL(columnsInserted(QModelIndex,int,int)),
+                        diagram, SLOT(setDataBoundariesDirty()) );
+            disconnect( attributesModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
+                        diagram, SLOT(setDataBoundariesDirty()) );
+            disconnect( attributesModel, SIGNAL(columnsRemoved(QModelIndex,int,int)),
+                        diagram, SLOT(setDataBoundariesDirty()) );
+            disconnect( attributesModel, SIGNAL(modelReset()),
+                        diagram, SLOT(setDataBoundariesDirty()) );
+            disconnect( attributesModel, SIGNAL(layoutChanged()),
+                        diagram, SLOT(setDataBoundariesDirty()) );
+            disconnect( attributesModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
+                        diagram, SIGNAL(modelDataChanged()));
         }
     }
 
     emit diagram->attributesModelAboutToChange( amodel, attributesModel );
 
-    connect( amodel, SIGNAL( rowsInserted( QModelIndex, int, int ) ),
-             diagram, SLOT( setDataBoundariesDirty() ) );
-    connect( amodel, SIGNAL( columnsInserted( QModelIndex, int, int ) ),
-             diagram, SLOT( setDataBoundariesDirty() ) );
-    connect( amodel, SIGNAL( rowsRemoved( QModelIndex, int, int ) ),
-             diagram, SLOT( setDataBoundariesDirty() ) );
-    connect( amodel, SIGNAL( columnsRemoved( QModelIndex, int, int ) ),
-             diagram, SLOT( setDataBoundariesDirty() ) );
-    connect( amodel, SIGNAL( modelReset() ),
-             diagram, SLOT( setDataBoundariesDirty() ) );
-    connect( amodel, SIGNAL( layoutChanged() ),
-             diagram, SLOT( setDataBoundariesDirty() ) );
-    connect( amodel, SIGNAL( dataChanged( QModelIndex, QModelIndex ) ),
-             diagram, SIGNAL( modelDataChanged() ));
+    connect( amodel, SIGNAL(rowsInserted(QModelIndex,int,int)),
+             diagram, SLOT(setDataBoundariesDirty()) );
+    connect( amodel, SIGNAL(columnsInserted(QModelIndex,int,int)),
+             diagram, SLOT(setDataBoundariesDirty()) );
+    connect( amodel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
+             diagram, SLOT(setDataBoundariesDirty()) );
+    connect( amodel, SIGNAL(columnsRemoved(QModelIndex,int,int)),
+             diagram, SLOT(setDataBoundariesDirty()) );
+    connect( amodel, SIGNAL(modelReset()),
+             diagram, SLOT(setDataBoundariesDirty()) );
+    connect( amodel, SIGNAL(layoutChanged()),
+             diagram, SLOT(setDataBoundariesDirty()) );
+    connect( amodel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
+             diagram, SIGNAL(modelDataChanged()));
 
     attributesModel = amodel;
 }
 
 AbstractDiagram::Private::Private( const AbstractDiagram::Private& rhs ) :
-    diagram( 0 ),
+    diagram( nullptr ),
     doDumpPaintTime( rhs.doDumpPaintTime ),
     // Do not copy the plane
-    plane( 0 ),
+    plane( nullptr ),
     attributesModelRootIndex( QModelIndex() ),
     attributesModel( rhs.attributesModel ),
     allowOverlappingDataValueTexts( rhs.allowOverlappingDataValueTexts ),
@@ -163,7 +163,7 @@ AbstractDiagram::Private::Private( const AbstractDiagram::Private& rhs ) :
     datasetDimension( rhs.datasetDimension ),
     mCachedFontMetrics( rhs.cachedFontMetrics() )
 {
-    attributesModel = new PrivateAttributesModel( 0, 0);
+    attributesModel = new PrivateAttributesModel( nullptr, nullptr);
     attributesModel->initFrom( rhs.attributesModel );
 }
 
@@ -253,7 +253,7 @@ void AbstractDiagram::Private::addLabel(
 
         const QRectF plainRect = doc.documentLayout()->frameBoundingRect( doc.rootFrame() );
 
-        /**
+        /*
         * A few hints on how the positioning of the text frame is done:
         *
         * Let's assume we have a bar chart, a text for a positive value
@@ -586,7 +586,7 @@ void AbstractDiagram::Private::paintDataValueText(
 QModelIndex AbstractDiagram::Private::indexAt( const QPoint& point ) const
 {
     QModelIndexList l = indexesAt( point );
-    qSort( l );
+    std::sort(l.begin(), l.end());
     if ( !l.isEmpty() )
         return l.first();
     else
