@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartChart.h"
@@ -151,7 +151,7 @@ using namespace KChart;
 class MyWidgetItem : public QWidgetItem
 {
 public:
-    explicit MyWidgetItem(QWidget *w, Qt::Alignment alignment = 0)
+    explicit MyWidgetItem(QWidget *w, Qt::Alignment alignment = Qt::Alignment())
         : QWidgetItem( w )
     {
         setAlignment( alignment );
@@ -164,19 +164,19 @@ public:
     // the Legends/Advanced example. It will not work well in various ways - won't get enough space and look
     // very broken, will inhibit resizing the window etc.
 
-    QSize sizeHint() const Q_DECL_OVERRIDE
+    QSize sizeHint() const override
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         return w->sizeHint();
     }
 
-    QSize minimumSize() const Q_DECL_OVERRIDE
+    QSize minimumSize() const override
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         return w->minimumSize();
     }
 
-    QSize maximumSize() const Q_DECL_OVERRIDE
+    QSize maximumSize() const override
     {
         // Not just passing on w->maximumSize() fixes that the size policy of Legend is disregarded, making
         // Legend take all available space, which makes both the Legend internal layout and the overall
@@ -197,29 +197,29 @@ public:
         return ret;
     }
 
-    Qt::Orientations expandingDirections() const Q_DECL_OVERRIDE
+    Qt::Orientations expandingDirections() const override
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         if ( isEmpty() ) {
-            return Qt::Orientations(0);
+            return Qt::Orientations();
         }
         Qt::Orientations e = w->sizePolicy().expandingDirections();
         return e;
     }
 
-    void setGeometry(const QRect &g) Q_DECL_OVERRIDE
+    void setGeometry(const QRect &g) override
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         w->setGeometry(g);
     }
 
-    QRect geometry() const Q_DECL_OVERRIDE
+    QRect geometry() const override
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         return w->geometry();
     }
 
-    bool hasHeightForWidth() const Q_DECL_OVERRIDE
+    bool hasHeightForWidth() const override
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         bool ret = !isEmpty() &&
@@ -227,14 +227,14 @@ public:
         return ret;
     }
 
-    int heightForWidth( int width ) const Q_DECL_OVERRIDE
+    int heightForWidth( int width ) const override
     {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         int ret = w->heightForWidth( width );
         return ret;
     }
 
-    bool isEmpty() const Q_DECL_OVERRIDE {
+    bool isEmpty() const override {
         QWidget* w = const_cast< MyWidgetItem * >( this )->widget();
         // legend->hide() should indeed hide the legend,
         // but a legend in a chart that hasn't been shown yet isn't hidden
@@ -275,7 +275,7 @@ void Chart::Private::slotUnregisterDestroyedPlane( AbstractCoordinatePlane* plan
     coordinatePlanes.removeAll( plane );
     Q_FOREACH ( AbstractCoordinatePlane* p, coordinatePlanes ) {
         if ( p->referenceCoordinatePlane() == plane) {
-            p->setReferenceCoordinatePlane( 0 );
+            p->setReferenceCoordinatePlane( nullptr );
         }
     }
     plane->layoutPlanes();
@@ -284,27 +284,27 @@ void Chart::Private::slotUnregisterDestroyedPlane( AbstractCoordinatePlane* plan
 Chart::Private::Private( Chart* chart_ )
     : chart( chart_ )
     , useNewLayoutSystem( false )
-    , layout( 0 )
-    , vLayout( 0 )
-    , planesLayout( 0 )
-    , headerLayout( 0 )
-    , footerLayout( 0 )
-    , dataAndLegendLayout( 0 )
-    , leftOuterSpacer( 0 )
-    , rightOuterSpacer( 0 )
-    , topOuterSpacer( 0 )
-    , bottomOuterSpacer( 0 )
+    , layout(nullptr)
+    , vLayout(nullptr)
+    , planesLayout(nullptr)
+    , headerLayout(nullptr)
+    , footerLayout(nullptr)
+    , dataAndLegendLayout(nullptr)
+    , leftOuterSpacer(nullptr)
+    , rightOuterSpacer(nullptr)
+    , topOuterSpacer(nullptr)
+    , bottomOuterSpacer(nullptr)
     , isFloatingLegendsLayoutDirty( true )
     , isPlanesLayoutDirty( true )
-    , globalLeadingLeft( 0 )
-    , globalLeadingRight( 0 )
-    , globalLeadingTop( 0 )
-    , globalLeadingBottom( 0 )
+    , globalLeadingLeft(0)
+    , globalLeadingRight(0)
+    , globalLeadingTop(0)
+    , globalLeadingBottom(0)
 {
     for ( int row = 0; row < 3; ++row ) {
         for ( int column = 0; column < 3; ++column ) {
             for ( int i = 0; i < 2; i++ ) {
-                innerHdFtLayouts[ i ][ row ][ column ] = 0;
+                innerHdFtLayouts[ i ][ row ][ column ] = nullptr;
             }
         }
     }
@@ -465,7 +465,7 @@ static CoordinatePlaneList findSharingAxisDiagrams( AbstractCoordinatePlane* pla
     return result;
 }
 
-/**
+/*
   * this method determines the needed layout of the graph
   * taking care of the sharing problematic
   * its NOT allowed to have a diagram that shares
@@ -638,9 +638,9 @@ QHash<AbstractCoordinatePlane*, PlaneInfo> Chart::Private::buildPlaneLayoutInfos
         }
         // Create a new grid layout for each plane that has no reference.
         p = planeInfos[plane];
-        if ( p.referencePlane == 0 ) {
+        if ( p.referencePlane == nullptr ) {
             p.gridLayout = new QGridLayout();
-            p.gridLayout->setMargin( 0 );
+            p.gridLayout->setContentsMargins( 0, 0, 0, 0 );
             planeInfos[plane] = p;
         }
     }
@@ -655,7 +655,7 @@ void Chart::Private::slotLayoutPlanes()
     if ( planesLayout && dataAndLegendLayout )
         dataAndLegendLayout->removeItem( planesLayout );
 
-    const bool hadPlanesLayout = planesLayout != 0;
+    const bool hadPlanesLayout = planesLayout != nullptr;
     int left, top, right, bottom;
     if ( hadPlanesLayout )
         planesLayout->getContentsMargins(&left, &top, &right, &bottom);
@@ -719,10 +719,10 @@ void Chart::Private::slotLayoutPlanes()
                         {
                             gridPlaneLayout->addItem( curColComponent->diagramPlane, row + planeRowOffset, col + planeColOffset, 2, 2 );
                             curColComponent->diagramPlane->setParentLayout( gridPlaneLayout );
-                            QHBoxLayout *leftLayout = 0;
-                            QHBoxLayout *rightLayout = 0;
-                            QVBoxLayout *topLayout = 0;
-                            QVBoxLayout *bottomLayout = 0;
+                            QHBoxLayout *leftLayout = nullptr;
+                            QHBoxLayout *rightLayout = nullptr;
+                            QVBoxLayout *topLayout = nullptr;
+                            QVBoxLayout *bottomLayout = nullptr;
                             if ( curComponent->sharedSuccesor )
                             {
                                 gridPlaneLayout->addItem( curColComponent->sharedSuccesor->diagramPlane, row + planeRowOffset, col + planeColOffset, 2, 2 );
@@ -831,7 +831,7 @@ void Chart::Private::slotLayoutPlanes()
             planesLayout->setContentsMargins( left, top, right, bottom );
         }
 
-        planesLayout->setMargin( 0 );
+        planesLayout->setContentsMargins( 0, 0, 0, 0 );
         planesLayout->setSpacing( 0 );
         planesLayout->setObjectName( QString::fromLatin1( "planesLayout" ) );
 
@@ -868,7 +868,7 @@ void Chart::Private::slotLayoutPlanes()
              * column of the shared grid. */
             planeLayoutItems << plane;
             plane->setParentLayout( planeLayout );
-            planeLayout->addItem( plane, row, column, 1, 1, 0 );
+            planeLayout->addItem( plane, row, column, 1, 1 );
             //qDebug() << "Chart slotLayoutPlanes() calls planeLayout->addItem("<< row << column << ")";
             planeLayout->setRowStretch( row, 2 );
             planeLayout->setColumnStretch( column, 2 );
@@ -880,7 +880,7 @@ void Chart::Private::slotLayoutPlanes()
                     continue;  // FIXME what about polar ?
                 }
 
-                if ( pi.referencePlane != 0 )
+                if ( pi.referencePlane != nullptr )
                 {
                     pi.topAxesLayout = planeInfos[ pi.referencePlane ].topAxesLayout;
                     pi.bottomAxesLayout = planeInfos[ pi.referencePlane ].bottomAxesLayout;
@@ -889,32 +889,32 @@ void Chart::Private::slotLayoutPlanes()
                 }
 
                 // collect all axes of a kind into sublayouts
-                if ( pi.topAxesLayout == 0 )
+                if ( pi.topAxesLayout == nullptr )
                 {
                     pi.topAxesLayout = new QVBoxLayout;
-                    pi.topAxesLayout->setMargin( 0 );
+                    pi.topAxesLayout->setContentsMargins( 0, 0, 0, 0 );
                     pi.topAxesLayout->setObjectName( QString::fromLatin1( "topAxesLayout" ) );
                 }
-                if ( pi.bottomAxesLayout == 0 )
+                if ( pi.bottomAxesLayout == nullptr )
                 {
                     pi.bottomAxesLayout = new QVBoxLayout;
-                    pi.bottomAxesLayout->setMargin( 0 );
+                    pi.bottomAxesLayout->setContentsMargins( 0, 0, 0, 0 );
                     pi.bottomAxesLayout->setObjectName( QString::fromLatin1( "bottomAxesLayout" ) );
                 }
-                if ( pi.leftAxesLayout == 0 )
+                if ( pi.leftAxesLayout == nullptr )
                 {
                     pi.leftAxesLayout = new QHBoxLayout;
-                    pi.leftAxesLayout->setMargin( 0 );
+                    pi.leftAxesLayout->setContentsMargins( 0, 0, 0, 0 );
                     pi.leftAxesLayout->setObjectName( QString::fromLatin1( "leftAxesLayout" ) );
                 }
-                if ( pi.rightAxesLayout == 0 )
+                if ( pi.rightAxesLayout == nullptr )
                 {
                     pi.rightAxesLayout = new QHBoxLayout;
-                    pi.rightAxesLayout->setMargin( 0 );
+                    pi.rightAxesLayout->setContentsMargins( 0, 0, 0, 0 );
                     pi.rightAxesLayout->setObjectName( QString::fromLatin1( "rightAxesLayout" ) );
                 }
 
-                if ( pi.referencePlane != 0 )
+                if ( pi.referencePlane != nullptr )
                 {
                     planeInfos[ pi.referencePlane ].topAxesLayout = pi.topAxesLayout;
                     planeInfos[ pi.referencePlane ].bottomAxesLayout = pi.bottomAxesLayout;
@@ -1009,7 +1009,7 @@ void Chart::Private::createLayouts()
 {
     // The toplevel layout provides the left and right global margins
     layout = new QHBoxLayout( chart );
-    layout->setMargin( 0 );
+    layout->setContentsMargins( 0, 0, 0, 0 );
     layout->setObjectName( QString::fromLatin1( "Chart::Private::layout" ) );
     layout->addSpacing( globalLeadingLeft );
     leftOuterSpacer = layout->itemAt( layout->count() - 1 )->spacerItem();
@@ -1017,7 +1017,7 @@ void Chart::Private::createLayouts()
     // The vLayout provides top and bottom global margins and lays
     // out headers, footers and the diagram area.
     vLayout = new QVBoxLayout();
-    vLayout->setMargin( 0 );
+    vLayout->setContentsMargins( 0, 0, 0, 0 );
     vLayout->setObjectName( QString::fromLatin1( "vLayout" ) );
 
     layout->addLayout( vLayout, 1000 );
@@ -1029,16 +1029,16 @@ void Chart::Private::createLayouts()
     topOuterSpacer = vLayout->itemAt( vLayout->count() - 1 )->spacerItem();
     // 2. the header area
     headerLayout = new QGridLayout();
-    headerLayout->setMargin( 0 );
+    headerLayout->setContentsMargins( 0, 0, 0, 0 );
     vLayout->addLayout( headerLayout );
     // 3. the area containing coordinate planes, axes, and legends
     dataAndLegendLayout = new QGridLayout();
-    dataAndLegendLayout->setMargin( 0 );
+    dataAndLegendLayout->setContentsMargins( 0, 0, 0, 0 );
     dataAndLegendLayout->setObjectName( QString::fromLatin1( "dataAndLegendLayout" ) );
     vLayout->addLayout( dataAndLegendLayout, 1000 );
     // 4. the footer area
     footerLayout = new QGridLayout();
-    footerLayout->setMargin( 0 );
+    footerLayout->setContentsMargins( 0, 0, 0, 0 );
     footerLayout->setObjectName( QString::fromLatin1( "footerLayout" ) );
     vLayout->addLayout( footerLayout );
 
@@ -1051,7 +1051,7 @@ void Chart::Private::createLayouts()
             const Qt::Alignment align = s_gridAlignments[ row ][ column ];
             for ( int headOrFoot = 0; headOrFoot < 2; headOrFoot++ ) {
                 QVBoxLayout* innerLayout = new QVBoxLayout();
-                innerLayout->setMargin( 0 );
+                innerLayout->setContentsMargins( 0, 0, 0, 0 );
                 innerLayout->setAlignment( align );
                 innerHdFtLayouts[ headOrFoot ][ row ][ column ] = innerLayout;
 
@@ -1219,7 +1219,7 @@ AbstractCoordinatePlane* Chart::coordinatePlane()
 {
     if ( d->coordinatePlanes.isEmpty() ) {
         qWarning() << "Chart::coordinatePlane: warning: no coordinate plane defined.";
-        return 0;
+        return nullptr;
     } else {
         return d->coordinatePlanes.first();
     }
@@ -1242,12 +1242,12 @@ void Chart::insertCoordinatePlane( int index, AbstractCoordinatePlane* plane )
         return;
     }
 
-    connect( plane, SIGNAL( destroyedCoordinatePlane( AbstractCoordinatePlane* ) ),
-             d,   SLOT( slotUnregisterDestroyedPlane( AbstractCoordinatePlane* ) ) );
-    connect( plane, SIGNAL( needUpdate() ),       this,   SLOT( update() ) );
-    connect( plane, SIGNAL( needRelayout() ),     d,      SLOT( slotResizePlanes() ) ) ;
-    connect( plane, SIGNAL( needLayoutPlanes() ), d,      SLOT( slotLayoutPlanes() ) ) ;
-    connect( plane, SIGNAL( propertiesChanged() ),this, SIGNAL( propertiesChanged() ) );
+    connect( plane, SIGNAL(destroyedCoordinatePlane(AbstractCoordinatePlane*)),
+             d,   SLOT(slotUnregisterDestroyedPlane(AbstractCoordinatePlane*)) );
+    connect( plane, SIGNAL(needUpdate()),       this,   SLOT(update()) );
+    connect( plane, SIGNAL(needRelayout()),     d,      SLOT(slotResizePlanes()) ) ;
+    connect( plane, SIGNAL(needLayoutPlanes()), d,      SLOT(slotLayoutPlanes()) ) ;
+    connect( plane, SIGNAL(propertiesChanged()),this, SIGNAL(propertiesChanged()) );
     d->coordinatePlanes.insert( index, plane );
     plane->setParent( this );
     d->slotLayoutPlanes();
@@ -1276,10 +1276,10 @@ void Chart::takeCoordinatePlane( AbstractCoordinatePlane* plane )
     const int idx = d->coordinatePlanes.indexOf( plane );
     if ( idx != -1 ) {
         d->coordinatePlanes.takeAt( idx );
-        disconnect( plane, 0, d, 0 );
-        disconnect( plane, 0, this, 0 );
+        disconnect( plane, nullptr, d, nullptr );
+        disconnect( plane, nullptr, this, nullptr );
         plane->removeFromParentLayout();
-        plane->setParent( 0 );
+        plane->setParent( nullptr );
         d->mouseClickedPlanes.removeAll(plane);
     }
     d->slotLayoutPlanes();
@@ -1354,7 +1354,6 @@ void Chart::paint( QPainter* painter, const QRect& rect )
     GlobalMeasureScaling::setPaintDevice( painter->device() );
     int prevScaleFactor = PrintingParameters::scaleFactor();
 
-    // Output onto a QPixmap
     PrintingParameters::setScaleFactor( qreal( painter->device()->logicalDpiX() ) / qreal( logicalDpiX() ) );
 
     const QRect oldGeometry( geometry() );
@@ -1440,10 +1439,10 @@ void Chart::addHeaderFooter( HeaderFooter* hf )
 
     d->headerFooters.append( hf );
     d->textLayoutItems.append( hf );
-    connect( hf, SIGNAL( destroyedHeaderFooter( HeaderFooter* ) ),
-             d, SLOT( slotUnregisterDestroyedHeaderFooter( HeaderFooter* ) ) );
-    connect( hf, SIGNAL( positionChanged( HeaderFooter* ) ),
-             d, SLOT( slotHeaderFooterPositionChanged( HeaderFooter* ) ) );
+    connect( hf, SIGNAL(destroyedHeaderFooter(HeaderFooter*)),
+             d, SLOT(slotUnregisterDestroyedHeaderFooter(HeaderFooter*)) );
+    connect( hf, SIGNAL(positionChanged(HeaderFooter*)),
+             d, SLOT(slotHeaderFooterPositionChanged(HeaderFooter*)) );
 
     // set the text attributes (why?)
 
@@ -1490,12 +1489,12 @@ void Chart::takeHeaderFooter( HeaderFooter* headerFooter )
     if ( idx == -1 ) {
         return;
     }
-    disconnect( headerFooter, SIGNAL( destroyedHeaderFooter( HeaderFooter* ) ),
-                d, SLOT( slotUnregisterDestroyedHeaderFooter( HeaderFooter* ) ) );
+    disconnect( headerFooter, SIGNAL(destroyedHeaderFooter(HeaderFooter*)),
+                d, SLOT(slotUnregisterDestroyedHeaderFooter(HeaderFooter*)) );
 
     d->headerFooters.takeAt( idx );
     headerFooter->removeFromParentLayout();
-    headerFooter->setParentLayout( 0 );
+    headerFooter->setParentLayout( nullptr );
     d->textLayoutItems.remove( d->textLayoutItems.indexOf( headerFooter ) );
 
     d->slotResizePlanes();
@@ -1510,7 +1509,7 @@ void Chart::Private::slotHeaderFooterPositionChanged( HeaderFooter* hf )
 HeaderFooter* Chart::headerFooter()
 {
     if ( d->headerFooters.isEmpty() ) {
-        return 0;
+        return nullptr;
     } else {
         return d->headerFooters.first();
     }
@@ -1591,7 +1590,7 @@ void Chart::addLegendInternal( Legend* legend, bool setMeasures )
         if ( !alignmentsLayout ) {
             alignmentsLayout = new QGridLayout;
             d->dataAndLegendLayout->addLayout( alignmentsLayout, row, column );
-            alignmentsLayout->setMargin( 0 );
+            alignmentsLayout->setContentsMargins( 0, 0, 0, 0 );
         }
 
         // in case there are several legends in the same edge or corner with the same alignment, they are stacked
@@ -1616,17 +1615,17 @@ void Chart::addLegendInternal( Legend* legend, bool setMeasures )
         if ( !sameAlignmentLayout ) {
             sameAlignmentLayout = new QVBoxLayout;
             alignmentsLayout->addLayout( sameAlignmentLayout, row, column );
-            sameAlignmentLayout->setMargin( 0 );
+            sameAlignmentLayout->setContentsMargins( 0, 0, 0, 0 );
         }
 
         sameAlignmentLayout->addItem( new MyWidgetItem( legend, legend->alignment() ) );
     }
 
-    connect( legend, SIGNAL( destroyedLegend( Legend* ) ),
-             d, SLOT( slotUnregisterDestroyedLegend( Legend* ) ) );
-    connect( legend, SIGNAL( positionChanged( AbstractAreaWidget* ) ),
-             d, SLOT( slotLegendPositionChanged( AbstractAreaWidget* ) ) );
-    connect( legend, SIGNAL( propertiesChanged() ), this, SIGNAL( propertiesChanged() ) );
+    connect( legend, SIGNAL(destroyedLegend(Legend*)),
+             d, SLOT(slotUnregisterDestroyedLegend(Legend*)) );
+    connect( legend, SIGNAL(positionChanged(AbstractAreaWidget*)),
+             d, SLOT(slotLegendPositionChanged(AbstractAreaWidget*)) );
+    connect( legend, SIGNAL(propertiesChanged()), this, SIGNAL(propertiesChanged()) );
 
     d->slotResizePlanes();
 }
@@ -1656,10 +1655,10 @@ void Chart::takeLegend( Legend* legend )
     }
 
     d->legends.takeAt( idx );
-    disconnect( legend, 0, d, 0 );
-    disconnect( legend, 0, this, 0 );
+    disconnect( legend, nullptr, d, nullptr );
+    disconnect( legend, nullptr, this, nullptr );
     // the following removes the legend from its layout and destroys its MyWidgetItem (the link to the layout)
-    legend->setParent( 0 );
+    legend->setParent( nullptr );
 
     d->slotResizePlanes();
     emit propertiesChanged();
@@ -1667,7 +1666,7 @@ void Chart::takeLegend( Legend* legend )
 
 Legend* Chart::legend()
 {
-    return d->legends.isEmpty() ? 0 : d->legends.first();
+    return d->legends.isEmpty() ? nullptr : d->legends.first();
 }
 
 LegendList Chart::legends()
