@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartHeaderFooter.h"
@@ -84,12 +84,9 @@ void HeaderFooter::init()
     setTextAttributes( ta );
 }
 
-/**
-  * Creates an exact copy of this header/footer.
-  */
 HeaderFooter * HeaderFooter::clone() const
 {
-    HeaderFooter* headerFooter = new HeaderFooter( new Private( *d ), 0 );
+    HeaderFooter* headerFooter = new HeaderFooter( new Private( *d ), nullptr );
     headerFooter->setType( type() );
     headerFooter->setPosition( position() );
     headerFooter->setText( text() );
