@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "KChartLegend.h"
@@ -26,6 +26,7 @@
 #include "KTextDocument.h"
 #include <KChartDiagramObserver.h>
 #include "KChartLayoutItems.h"
+#include "KChartPrintingParameters.h"
 
 #include <QFont>
 #include <QGridLayout>
@@ -42,7 +43,7 @@
 using namespace KChart;
 
 Legend::Private::Private() :
-    referenceArea( 0 ),
+    referenceArea( nullptr ),
     position( Position::East ),
     alignment( Qt::AlignCenter ),
     textAlignment( Qt::AlignCenter ),
@@ -98,7 +99,7 @@ void Legend::init()
     setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
 
     d->layout = new QGridLayout( this );
-    d->layout->setMargin( 2 );
+    d->layout->setContentsMargins( 2, 2, 2, 2 );
     d->layout->setSpacing( d->spacing );
 
     const Measure normalFontSizeTitle( 12, KChartEnums::MeasureCalculationModeAbsolute );
@@ -189,12 +190,9 @@ Legend::LegendStyle Legend::legendStyle() const
     return d->legendStyle;
 }
 
-/**
-  * Creates an exact copy of this legend.
-  */
 Legend* Legend::clone() const
 {
-    Legend* legend = new Legend( new Private( *d ), 0 );
+    Legend* legend = new Legend( new Private( *d ), nullptr );
     legend->setTextAttributes( textAttributes() );
     legend->setTitleTextAttributes( titleTextAttributes() );
     legend->setFrameAttributes( frameAttributes() );
@@ -257,6 +255,30 @@ void Legend::paint( QPainter* painter )
 #endif
 }
 
+void Legend::paint( QPainter *painter, const QRect& rect )
+{
+    if ( rect.isEmpty() ) {
+        return;
+    }
+    // set up the contents of the widget so we get a useful geometry
+    QPaintDevice* prevDevice = GlobalMeasureScaling::paintDevice();
+    GlobalMeasureScaling::setPaintDevice( painter->device() );
+
+    const QRect oldGeometry(geometry() );
+    const QRect newGeo( QPoint(0,0), rect.size() );
+    if (oldGeometry != newGeo) {
+        setGeometry(newGeo);
+        needSizeHint();
+    }
+    painter->translate( rect.left(), rect.top() );
+    paintAll( *painter );
+    painter->translate( -rect.left(), -rect.top() );
+
+    if (oldGeometry != newGeo) {
+        setGeometry(oldGeometry);
+    }
+    GlobalMeasureScaling::setPaintDevice( prevDevice );
+}
 
 uint Legend::datasetCount() const
 {
@@ -288,7 +310,7 @@ const QWidget* Legend::referenceArea() const
 AbstractDiagram* Legend::diagram() const
 {
     if ( d->observers.isEmpty() ) {
-        return 0;
+        return nullptr;
     }
     return d->observers.first()->diagram();
 }
@@ -323,14 +345,14 @@ void Legend::addDiagram( AbstractDiagram* newDiagram )
         } else {
             d->observers.append( observer );
         }
-        connect( observer, SIGNAL( diagramAboutToBeDestroyed(AbstractDiagram*) ),
-                 SLOT( resetDiagram(AbstractDiagram*) ));
-        connect( observer, SIGNAL( diagramDataChanged(AbstractDiagram*) ),
-                 SLOT( setNeedRebuild() ));
-        connect( observer, SIGNAL( diagramDataHidden(AbstractDiagram*) ),
-                 SLOT( setNeedRebuild() ));
-        connect( observer, SIGNAL( diagramAttributesChanged(AbstractDiagram*) ),
-                 SLOT( setNeedRebuild() ));
+        connect( observer, SIGNAL(diagramAboutToBeDestroyed(AbstractDiagram*)),
+                 SLOT(resetDiagram(AbstractDiagram*)));
+        connect( observer, SIGNAL(diagramDataChanged(AbstractDiagram*)),
+                 SLOT(setNeedRebuild()));
+        connect( observer, SIGNAL(diagramDataHidden(AbstractDiagram*)),
+                 SLOT(setNeedRebuild()));
+        connect( observer, SIGNAL(diagramAttributesChanged(AbstractDiagram*)),
+                 SLOT(setNeedRebuild()));
         setNeedRebuild();
     }
 }
@@ -570,11 +592,6 @@ bool Legend::useAutomaticMarkerSize() const
     return d->useAutomaticMarkerSize;
 }
 
-/**
-    \brief Removes all legend texts that might have been set by setText.
-
-    This resets the Legend to default behaviour: Texts are created automatically.
-*/
 void Legend::resetTexts()
 {
     if ( !d->texts.count() ) {
@@ -880,10 +897,10 @@ QSizeF Legend::Private::maxMarkerSize( Legend *q, qreal fontHeight ) const
 }
 
 HDatasetItem::HDatasetItem()
-   : markerLine(0),
-     label(0),
-     separatorLine(0),
-     spacer(0)
+   : markerLine(nullptr),
+     label(nullptr),
+     separatorLine(nullptr),
+     spacer(nullptr)
 {}
 
 static void updateToplevelLayout(QWidget *w)
@@ -1156,11 +1173,11 @@ void Legend::Private::flowHDatasetItems( Legend *q )
         // those have no parents in the current layout, so they wouldn't get cleaned up otherwise
         if ( !spacerUsed ) {
             delete hdsItem->spacer;
-            hdsItem->spacer = 0;
+            hdsItem->spacer = nullptr;
         }
         if ( !separatorUsed ) {
             delete hdsItem->separatorLine;
-            hdsItem->separatorLine = 0;
+            hdsItem->separatorLine = nullptr;
         }
 
         currentLine->addItem( hdsItem->markerLine );
