@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KCHARTABSTRACTTERNARYDIAGRAM_P_H
@@ -59,7 +59,7 @@ namespace KChart {
             AbstractDiagram::Private( rhs ),
             // Do not copy axes and reference diagrams.
             axesList(),
-            referenceDiagram( 0 ),
+            referenceDiagram( nullptr ),
             referenceDiagramOffset()
         {
         }
