@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "kganttconstraintproxy.h"
@@ -24,9 +24,7 @@
 
 using namespace KGantt;
 
-/*!\class KGantt::ConstraintProxy
- * \internal
- */
+
 
 ConstraintProxy::ConstraintProxy( QObject* parent )
     : QObject( parent )
@@ -44,10 +42,10 @@ void ConstraintProxy::setSourceModel( ConstraintModel* src )
 
     copyFromSource();
 
-    connect( m_source, SIGNAL( constraintAdded( const KGantt::Constraint& ) ),
-             this, SLOT( slotSourceConstraintAdded( const KGantt::Constraint& ) ) );
-    connect( m_source, SIGNAL( constraintRemoved( const KGantt::Constraint& ) ),
-             this, SLOT( slotSourceConstraintRemoved( const KGantt::Constraint& ) ) );
+    connect( m_source, SIGNAL(constraintAdded(KGantt::Constraint)),
+             this, SLOT(slotSourceConstraintAdded(KGantt::Constraint)) );
+    connect( m_source, SIGNAL(constraintRemoved(KGantt::Constraint)),
+             this, SLOT(slotSourceConstraintRemoved(KGantt::Constraint)) );
 }
 
 void ConstraintProxy::setDestinationModel( ConstraintModel* dest )
@@ -57,10 +55,10 @@ void ConstraintProxy::setDestinationModel( ConstraintModel* dest )
 
     copyFromSource();
 
-    connect( m_destination, SIGNAL( constraintAdded( const KGantt::Constraint& ) ),
-             this, SLOT( slotDestinationConstraintAdded( const KGantt::Constraint& ) ) );
-    connect( m_destination, SIGNAL( constraintRemoved( const KGantt::Constraint& ) ),
-             this, SLOT( slotDestinationConstraintRemoved( const KGantt::Constraint& ) ) );
+    connect( m_destination, SIGNAL(constraintAdded(KGantt::Constraint)),
+             this, SLOT(slotDestinationConstraintAdded(KGantt::Constraint)) );
+    connect( m_destination, SIGNAL(constraintRemoved(KGantt::Constraint)),
+             this, SLOT(slotDestinationConstraintRemoved(KGantt::Constraint)) );
 }
 
 void ConstraintProxy::setProxyModel( QAbstractProxyModel* proxy )
@@ -69,8 +67,8 @@ void ConstraintProxy::setProxyModel( QAbstractProxyModel* proxy )
     if ( m_proxy ) m_proxy->disconnect( this );
     m_proxy = proxy;
     if ( m_proxy ) {
-        connect( m_proxy, SIGNAL( layoutChanged() ), this, SLOT( slotLayoutChanged() ) );
-        connect( m_proxy, SIGNAL( modelReset() ), this, SLOT( slotLayoutChanged() ) );
+        connect( m_proxy, SIGNAL(layoutChanged()), this, SLOT(slotLayoutChanged()) );
+        connect( m_proxy, SIGNAL(modelReset()), this, SLOT(slotLayoutChanged()) );
     }
 }
 
