@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "kganttdatetimegrid.h"
@@ -32,6 +32,7 @@
 #include <QString>
 #include <QDebug>
 #include <QList>
+#include <QPainterPath>
 
 #include <cassert>
 
@@ -52,12 +53,7 @@ QDebug operator<<( QDebug dbg, KGantt::DateTimeScaleFormatter::Range range )
 }
 
 
-/*!\class KGantt::DateTimeGrid
- * \ingroup KGantt
- *
- * This implementation of AbstractGrid works with QDateTime
- * and shows days and week numbers in the header
- */
+
 
 qreal DateTimeGrid::Private::dateTimeToChartX( const QDateTime& dt ) const
 {
@@ -83,33 +79,9 @@ QDateTime DateTimeGrid::Private::chartXtoDateTime( qreal x ) const
 
 #define d d_func()
 
-/*!\class KGantt::DateTimeScaleFormatter
- * \ingroup KGantt
- *
- * This class formats dates and times used in DateTimeGrid follawing a given format.
- *
- * The format follows the format of QDateTime::toString(), with one addition:
- * "w" is replaced with the week number of the date as number without a leading zero (1-53)
- * "ww" is replaced with the week number of the date as number with a leading zero (01-53)
- *
- * For example:
- *
- * \code
- *  // formatter to print the complete date over the current week
- *  // This leads to the first day of the week being printed
- *  DateTimeScaleFormatter formatter = DateTimeScaleFormatter( DateTimeScaleFormatter::Week, "yyyy-MM-dd" );
- * \endcode
- *
- * Optionally, you can set an user defined text alignment flag. The default value is Qt::AlignCenter.
- * \sa DateTimeScaleFormatter::DateTimeScaleFormatter
- *
- * This class even controls the range of the grid sections.
- * \sa KGanttDateTimeScaleFormatter::Range
- */
 
-/*! Creates a DateTimeScaleFormatter using \a range and \a format.
- *  The text on the header is aligned following \a alignment.
- */
+
+
 DateTimeScaleFormatter::DateTimeScaleFormatter( Range range, const QString& format,
                                                 const QString& templ, Qt::Alignment alignment )
     : _d( new Private( range, format, templ, alignment ) )
@@ -141,15 +113,13 @@ DateTimeScaleFormatter& DateTimeScaleFormatter::operator=( const DateTimeScaleFo
     return *this;
 }
 
-/*! \returns The format being used for formatting dates and times.
- */
+
 QString DateTimeScaleFormatter::format() const
 {
     return d->format;
 }
 
-/*! \returns The \a datetime as string respecting the format.
- */
+
 QString DateTimeScaleFormatter::format( const QDateTime& datetime ) const
 {
     QString result = d->format;
@@ -168,8 +138,7 @@ QString DateTimeScaleFormatter::text( const QDateTime& datetime ) const
     return d->templ.arg( format( datetime ) );
 }
 
-/*! \returns The range of each item on a DateTimeGrid header.
- * \sa DateTimeScaleFormatter::Range */
+
 DateTimeScaleFormatter::Range DateTimeScaleFormatter::range() const
 {
     return d->range;
@@ -180,9 +149,7 @@ Qt::Alignment DateTimeScaleFormatter::alignment() const
     return d->alignment;
 }
 
-/*! \returns the QDateTime being the begin of the range after the one containing \a datetime
- *  \sa currentRangeBegin
- */
+
 QDateTime DateTimeScaleFormatter::nextRangeBegin( const QDateTime& datetime ) const
 {
     QDateTime result = datetime;
@@ -235,9 +202,7 @@ QDateTime DateTimeScaleFormatter::nextRangeBegin( const QDateTime& datetime ) co
     return result;
 }
 
-/*! \returns the QDateTime being the begin of the range containing \a datetime
- *  \sa nextRangeBegin
- */
+
 QDateTime DateTimeScaleFormatter::currentRangeBegin( const QDateTime& datetime ) const
 {
     QDateTime result = datetime;
@@ -291,53 +256,38 @@ DateTimeGrid::~DateTimeGrid()
 {
 }
 
-/*! \returns The QDateTime used as start date for the grid.
- *
- * The default is three days before the current date.
- */
+
 QDateTime DateTimeGrid::startDateTime() const
 {
     return d->startDateTime;
 }
 
-/*! \param dt The start date of the grid. It is used as the beginning of the
- * horizontal scrollbar in the view.
- *
- * Emits gridChanged() after the start date has changed.
- */
+
 void DateTimeGrid::setStartDateTime( const QDateTime& dt )
 {
     d->startDateTime = dt;
     emit gridChanged();
 }
 
-/*! \returns The width in pixels for each day in the grid.
- *
- * The default is 100 pixels.
- */
+
 qreal DateTimeGrid::dayWidth() const
 {
     return d->dayWidth;
 }
 
-/*! Maps a given point in time \a dt to an X value in the scene.
- */
+
 qreal DateTimeGrid::mapFromDateTime( const QDateTime& dt) const
 {
     return d->dateTimeToChartX( dt );
 }
 
-/*! Maps a given X value \a x in scene coordinates to a point in time.
- */
+
 QDateTime DateTimeGrid::mapToDateTime( qreal x ) const
 {
     return d->chartXtoDateTime( x );
 }
 
-/*! \param w The width in pixels for each day in the grid.
- *
- * The signal gridChanged() is emitted after the day width is changed.
- */
+
 void DateTimeGrid::setDayWidth( qreal w )
 {
     assert( w>0 );
@@ -345,44 +295,20 @@ void DateTimeGrid::setDayWidth( qreal w )
     emit gridChanged();
 }
 
-/*! \param s The scale to be used to paint the grid.
- *
- * The signal gridChanged() is emitted after the scale has changed.
- * \sa Scale
- *
- * Following example demonstrates how to change the format of the header to use
- * a date-scaling with the header-label displayed with the ISO date-notation.
- * \code
- * DateTimeScaleFormatter* formatter = new DateTimeScaleFormatter(DateTimeScaleFormatter::Day, QString::fromLatin1("yyyy-MMMM-dddd"));
- * grid->setUserDefinedUpperScale( formatter );
- * grid->setUserDefinedLowerScale( formatter );
- * grid->setScale( DateTimeGrid::ScaleUserDefined );
- * \endcode
- */
+
 void DateTimeGrid::setScale( Scale s )
 {
     d->scale = s;
     emit gridChanged();
 }
 
-/*! \returns The scale used to paint the grid.
- *
- * The default is ScaleAuto, which means the day scale will be used
- * as long as the day width is less or equal to 500.
- * \sa Scale
- */
+
 DateTimeGrid::Scale DateTimeGrid::scale() const
 {
     return d->scale;
 }
 
-/*! Sets the scale formatter for the lower part of the header to the
- *  user defined formatter to \a lower. The DateTimeGrid object takes
- *  ownership of the formatter, which has to be allocated with new.
- *
- * You have to set the scale to ScaleUserDefined for this setting to take effect.
- * \sa DateTimeScaleFormatter
- */
+
 void DateTimeGrid::setUserDefinedLowerScale( DateTimeScaleFormatter* lower )
 {
     delete d->lower;
@@ -390,13 +316,7 @@ void DateTimeGrid::setUserDefinedLowerScale( DateTimeScaleFormatter* lower )
     emit gridChanged();
 }
 
-/*! Sets the scale formatter for the upper part of the header to the
- *  user defined formatter to \a upper. The DateTimeGrid object takes
- *  ownership of the formatter, which has to be allocated with new.
- *
- * You have to set the scale to ScaleUserDefined for this setting to take effect.
- * \sa DateTimeScaleFormatter
- */
+
 void DateTimeGrid::setUserDefinedUpperScale( DateTimeScaleFormatter* upper )
 {
     delete d->upper;
@@ -404,102 +324,81 @@ void DateTimeGrid::setUserDefinedUpperScale( DateTimeScaleFormatter* upper )
     emit gridChanged();
 }
 
-/*! \return The DateTimeScaleFormatter being used to render the lower scale.
- */
+
 DateTimeScaleFormatter* DateTimeGrid::userDefinedLowerScale() const
 {
     return d->lower;
 }
 
-/*! \return The DateTimeScaleFormatter being used to render the upper scale.
- */
+
 DateTimeScaleFormatter* DateTimeGrid::userDefinedUpperScale() const
 {
     return d->upper;
 }
 
-/*! \param ws The start day of the week.
- *
- * A solid line is drawn on the grid to mark the beginning of a new week.
- * Emits gridChanged() after the start day has changed.
- */
+
 void DateTimeGrid::setWeekStart( Qt::DayOfWeek ws )
 {
     d->weekStart = ws;
     emit gridChanged();
 }
 
-/*! \returns The start day of the week */
+
 Qt::DayOfWeek DateTimeGrid::weekStart() const
 {
     return d->weekStart;
 }
 
-/*! \param fd A set of days to mark as free in the grid.
- *
- * Free days are filled with the alternate base brush of the
- * palette used by the view.
- * The signal gridChanged() is emitted after the free days are changed.
- */
+
 void DateTimeGrid::setFreeDays( const QSet<Qt::DayOfWeek>& fd )
 {
     d->freeDays = fd;
     emit gridChanged();
 }
 
-/*! \returns The days marked as free in the grid. */
+
 QSet<Qt::DayOfWeek> DateTimeGrid::freeDays() const
 {
     return d->freeDays;
 }
 
-/*! Sets the brush to use to paint free days.
-*/
+
 void DateTimeGrid::setFreeDaysBrush(const QBrush brush)
 {
     d->freeDaysBrush = brush;
 }
 
-/*!
-  \returns The brush used to paint free days.
-*/
+
 QBrush DateTimeGrid::freeDaysBrush() const
 {
     return d->freeDaysBrush;
 }
 
-/*! \returns true if row separators are used. */
+
 bool DateTimeGrid::rowSeparators() const
 {
     return d->rowSeparators;
 }
-/*! \param enable Whether to use row separators or not. */
+
 void DateTimeGrid::setRowSeparators( bool enable )
 {
     d->rowSeparators = enable;
 }
 
-/*! Sets the brush used to display rows where no data is found.
- * Default is a red pattern. If set to QBrush() rows with no
- * information will not be marked.
- */
+
 void DateTimeGrid::setNoInformationBrush( const QBrush& brush )
 {
     d->noInformationBrush = brush;
     emit gridChanged();
 }
 
-/*! \returns the brush used to mark rows with no information.
- */
+
 QBrush DateTimeGrid::noInformationBrush() const
 {
     return d->noInformationBrush;
 }
 
-/*!
- * \param value The datetime to get the x value for.
- * \returns The x value corresponding to \a value or -1.0 if \a value is not a datetime variant.
- */
+
 qreal DateTimeGrid::mapToChart( const QVariant& value ) const
 {
     if ( ! value.canConvert( QVariant::DateTime ) ||
@@ -510,18 +409,13 @@ qreal DateTimeGrid::mapToChart( const QVariant& value ) const
     return d->dateTimeToChartX( value.toDateTime() );
 }
 
-/*!
- * \param x The x value get the datetime for.
- * \returns The datetime corresponding to \a x or an invalid datetime if x cannot be mapped.
- */
+
 QVariant DateTimeGrid::mapFromChart( qreal x ) const
 {
     return d->chartXtoDateTime( x );
 }
 
-/*! \param idx The index to get the Span for.
- * \returns The start and end pixels, in a Span, of the specified index.
- */
+
 Span DateTimeGrid::mapToChart( const QModelIndex& idx ) const
 {
     assert( model() );
@@ -567,20 +461,7 @@ static void debug_print_idx( const QModelIndex& idx )
 }
 #endif
 
-/*! Maps the supplied Span to QDateTimes, and puts them as start time and
- * end time for the supplied index.
- *
- * \param span The span used to map from.
- * \param idx The index used for setting the start time and end time in the model.
- * \param constraints A list of hard constraints to match against the start time and
- * end time mapped from the span.
- *
- * \returns true if the start time and time was successfully added to the model, or false
- * if unsucessful.
- * Also returns false if any of the constraints isn't satisfied. That is, if the start time of
- * the constrained index is before the end time of the dependency index, or the end time of the
- * constrained index is before the start time of the dependency index.
- */
+
 bool DateTimeGrid::mapFromChart( const Span& span, const QModelIndex& idx,
     const QList<Constraint>& constraints ) const
 {
@@ -604,8 +485,8 @@ bool DateTimeGrid::mapFromChart( const Span& span, const QModelIndex& idx,
         }
     }
 
-    return model()->setData( idx, qVariantFromValue(st), StartTimeRole )
-        && model()->setData( idx, qVariantFromValue(et), EndTimeRole );
+    return model()->setData( idx, QVariant::fromValue(st), StartTimeRole )
+        && model()->setData( idx, QVariant::fromValue(et), EndTimeRole );
 }
 
 Qt::PenStyle DateTimeGrid::Private::gridLinePenStyle( QDateTime dt, Private::HeaderType headerType ) const
@@ -782,7 +663,7 @@ void DateTimeGrid::paintGrid( QPainter* painter,
         d->paintVerticalLines( painter, sceneRect, exposedRect, widget, d->headerTypeForScale( scale() ) );
         break;
     case ScaleAuto: {
-        const qreal tabw = QApplication::fontMetrics().width( QLatin1String( "XXXXX" ) );
+        const qreal tabw = QApplication::fontMetrics().boundingRect( QLatin1String( "XXXXX" ) ).width();
         const qreal dayw = dayWidth();
         if ( dayw > 24*60*60*tabw ) {
 
@@ -844,7 +725,7 @@ int DateTimeGrid::Private::tabHeight( const QString& txt, QWidget* widget ) cons
 
 void DateTimeGrid::Private::getAutomaticFormatters( DateTimeScaleFormatter** lower, DateTimeScaleFormatter** upper)
 {
-    const qreal tabw = QApplication::fontMetrics().width( QLatin1String( "XXXXX" ) );
+    const qreal tabw = QApplication::fontMetrics().boundingRect( QLatin1String( "XXXXX" ) ).width();
     const qreal dayw = dayWidth;
     if ( dayw > 24*60*60*tabw ) {
         *lower = &minute_lower;
@@ -1000,9 +881,7 @@ void DateTimeGrid::Private::paintHeader( QPainter* painter,
     }
 }
 
-/*! Paints the hour scale header.
- * \sa paintHeader()
- */
+
 void DateTimeGrid::paintHourScaleHeader( QPainter* painter,
                                          const QRectF& headerRect, const QRectF& exposedRect,
                                          qreal offset, QWidget* widget )
@@ -1011,10 +890,10 @@ void DateTimeGrid::paintHourScaleHeader( QPainter* painter,
     public:
         virtual ~HourFormatter() {}
 
-        QString format( const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QString format( const QDateTime& dt ) override {
             return dt.time().toString( QString::fromLatin1( "hh" ) );
         }
-        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             Q_UNUSED(dt);
 
             return QRectF( QPointF( x, headerRect.top() ) + QPointF( -offset + 1.0, headerRect.height() / 2.0 ),
@@ -1027,10 +906,10 @@ void DateTimeGrid::paintHourScaleHeader( QPainter* painter,
     class DayFormatter : public Private::DateTextFormatter {
     public:
         virtual ~DayFormatter() {}
-        QString format( const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QString format( const QDateTime& dt ) override {
             return dt.date().toString();
         }
-        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             Q_UNUSED(dt);
 
             return QRectF( QPointF( x, headerRect.top() ) + QPointF( -offset, 0.0 ),
@@ -1041,9 +920,7 @@ void DateTimeGrid::paintHourScaleHeader( QPainter* painter,
                     Private::HeaderDay, new DayFormatter ); // Custom parameters
 }
 
-/*! Paints the day scale header.
- * \sa paintHeader()
- */
+
 void DateTimeGrid::paintDayScaleHeader( QPainter* painter,  const QRectF& headerRect, const QRectF& exposedRect,
                                 qreal offset, QWidget* widget )
 {
@@ -1051,10 +928,10 @@ void DateTimeGrid::paintDayScaleHeader( QPainter* painter,  const QRectF& header
     public:
         virtual ~DayFormatter() {}
 
-        QString format( const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QString format( const QDateTime& dt ) override {
             return dt.toString( QString::fromLatin1( "ddd" ) ).left( 1 );
         }
-        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             Q_UNUSED(dt);
 
             return QRectF( QPointF( x, headerRect.top() ) + QPointF( -offset + 1.0, headerRect.height() / 2.0 ),
@@ -1067,10 +944,10 @@ void DateTimeGrid::paintDayScaleHeader( QPainter* painter,  const QRectF& header
     class WeekFormatter : public Private::DateTextFormatter {
     public:
         virtual ~WeekFormatter() {}
-        QString format( const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QString format( const QDateTime& dt ) override {
             return QString::number(dt.date().weekNumber()) + QLatin1String("/") + QString::number(dt.date().year());
         }
-        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             Q_UNUSED(dt);
 
             return QRectF( QPointF( x, headerRect.top() ) + QPointF( -offset, 0.0 ),
@@ -1081,9 +958,7 @@ void DateTimeGrid::paintDayScaleHeader( QPainter* painter,  const QRectF& header
                     Private::HeaderWeek, new WeekFormatter ); // Custom parameters
 }
 
-/*! Paints the week scale header.
- * \sa paintHeader()
- */
+
 void DateTimeGrid::paintWeekScaleHeader( QPainter* painter,  const QRectF& headerRect, const QRectF& exposedRect,
                                         qreal offset, QWidget* widget )
 {
@@ -1091,10 +966,10 @@ void DateTimeGrid::paintWeekScaleHeader( QPainter* painter,  const QRectF& heade
     public:
         virtual ~WeekFormatter() {}
 
-        QString format( const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QString format( const QDateTime& dt ) override {
             return QString::number( dt.date().weekNumber() );
         }
-        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             Q_UNUSED(dt);
 
             return QRectF( QPointF( x, headerRect.top() ) + QPointF( -offset, headerRect.height() / 2.0 ),
@@ -1108,10 +983,10 @@ void DateTimeGrid::paintWeekScaleHeader( QPainter* painter,  const QRectF& heade
     public:
         virtual ~MonthFormatter() {}
 
-        QString format( const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QString format( const QDateTime& dt ) override {
             return QLocale().monthName(dt.date().month(), QLocale::LongFormat) + QLatin1String("/") + QString::number(dt.date().year());
         }
-        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             return QRectF( QPointF( x, headerRect.top() ) + QPointF( -offset, 0.0 ),
                            QSizeF( dayWidth * dt.date().daysInMonth(), headerRect.height() / 2.0 ) ).toRect();
         }
@@ -1120,9 +995,7 @@ void DateTimeGrid::paintWeekScaleHeader( QPainter* painter,  const QRectF& heade
                     Private::HeaderMonth, new MonthFormatter ); // Custom parameters
 }
 
-/*! Paints the week scale header.
- * \sa paintHeader()
- */
+
 void DateTimeGrid::paintMonthScaleHeader( QPainter* painter,  const QRectF& headerRect, const QRectF& exposedRect,
                                         qreal offset, QWidget* widget )
 {
@@ -1130,10 +1003,10 @@ void DateTimeGrid::paintMonthScaleHeader( QPainter* painter,  const QRectF& head
     public:
         virtual ~MonthFormatter() {}
 
-        QString format( const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QString format( const QDateTime& dt ) override {
             return QLocale().monthName(dt.date().month(), QLocale::ShortFormat) + QLatin1String("/") + QString::number(dt.date().year());
         }
-        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             return QRectF( QPointF( x, headerRect.top() ) + QPointF( -offset, headerRect.height() / 2.0 ),
                            QSizeF( dayWidth * dt.date().daysInMonth(), headerRect.height() / 2.0 ) ).toRect();
         }
@@ -1145,10 +1018,10 @@ void DateTimeGrid::paintMonthScaleHeader( QPainter* painter,  const QRectF& head
     public:
         virtual ~YearFormatter() {}
 
-        QString format( const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QString format( const QDateTime& dt ) override {
             return QString::number( dt.date().year() );
         }
-        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) Q_DECL_OVERRIDE {
+        QRect textRect( qreal x, qreal offset, qreal dayWidth, const QRectF& headerRect, const QDateTime& dt ) override {
             return QRectF( QPointF( x, headerRect.top() ) + QPointF( -offset, 0.0 ),
                            QSizeF( dayWidth * dt.date().daysInYear(), headerRect.height() / 2.0 ) ).toRect();
         }
@@ -1157,26 +1030,25 @@ void DateTimeGrid::paintMonthScaleHeader( QPainter* painter,  const QRectF& head
                     Private::HeaderYear, new YearFormatter ); // Custom parameters
 }
 
-/*! Draw the background for a day.
-*/
+
 void DateTimeGrid::drawDayBackground(QPainter* painter, const QRectF& rect, const QDate& date)
 {
-    Q_UNUSED(painter);
-    Q_UNUSED(rect);
     Q_UNUSED(date);
+    if (d->timeLine->options() & DateTimeTimeLine::Background) {
+        d->drawTimeLine(painter, rect);
+    }
 }
 
-/*! Draw the foreground for a day.
-*/
+
 void DateTimeGrid::drawDayForeground(QPainter* painter, const QRectF& rect, const QDate& date)
 {
-    Q_UNUSED(painter);
-    Q_UNUSED(rect);
     Q_UNUSED(date);
+    if (d->timeLine->options() & DateTimeTimeLine::Foreground) {
+        d->drawTimeLine(painter, rect);
+    }
 }
 
-/** Return the rectangle that represents the date-range.
-*/
+
 QRectF DateTimeGrid::computeRect(const QDateTime& from, const QDateTime& to, const QRectF& rect) const
 {
     qreal topLeft = d->dateTimeToChartX(from);
@@ -1185,8 +1057,7 @@ QRectF DateTimeGrid::computeRect(const QDateTime& from, const QDateTime& to, con
     return QRectF(topLeft, rect.top(), topRight - topLeft, rect.height());
 }
 
-/** Return a date-range represented by the rectangle.
-*/
+
 QPair<QDateTime, QDateTime> DateTimeGrid::dateTimeRange(const QRectF& rect) const
 {
     QDateTime start;
@@ -1286,6 +1157,23 @@ void DateTimeGrid::drawForeground(QPainter* paint, const QRectF& rect)
     paint->restore();
 }
 
+
+DateTimeTimeLine *DateTimeGrid::timeLine() const
+{
+    return d->timeLine;
+}
+
+void DateTimeGrid::Private::drawTimeLine(QPainter* painter, const QRectF& rect)
+{
+    qreal x = dateTimeToChartX(timeLine->dateTime());
+    if (rect.contains(x, rect.top())) {
+        painter->save();
+        painter->setPen(timeLine->pen());
+        painter->drawLine(x, rect.top(), x, rect.bottom());
+        painter->restore();
+    }
+}
+
 #undef d
 
 #ifndef KDAB_NO_UNIT_TESTS
