@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KGANTTDATETIMEGRID_P_H
@@ -22,6 +22,7 @@
 
 #include "kganttdatetimegrid.h"
 #include "kganttabstractgrid_p.h"
+#include "kganttdatetimetimeline.h"
 
 #include <QDateTime>
 #include <QBrush>
@@ -71,19 +72,21 @@ namespace KGantt {
               hour_upper( DateTimeScaleFormatter::Hour, QString::fromLatin1("hh" ) ),
               hour_lower( DateTimeScaleFormatter::Minute, QString::fromLatin1("m" ) ),
               minute_upper( DateTimeScaleFormatter::Minute, QString::fromLatin1("m" ) ),
-              minute_lower( DateTimeScaleFormatter::Second, QString::fromLatin1("s" ) )
+              minute_lower( DateTimeScaleFormatter::Second, QString::fromLatin1("s" ) ),
+              timeLine(new DateTimeTimeLine)
         {
         }
         ~Private()
         {
             delete lower;
             delete upper;
+            delete timeLine;
         }
 
         qreal dateTimeToChartX( const QDateTime& dt ) const;
         QDateTime chartXtoDateTime( qreal x ) const;
 
-        int tabHeight( const QString& txt, QWidget* widget = 0 ) const;
+        int tabHeight( const QString& txt, QWidget* widget = nullptr ) const;
         void getAutomaticFormatters( DateTimeScaleFormatter** lower, DateTimeScaleFormatter** upper);
 
         class DateTextFormatter {
@@ -125,6 +128,8 @@ namespace KGantt {
         Qt::PenStyle gridLinePenStyle( QDateTime dt, HeaderType headerType ) const;
         QDateTime adjustDateTimeForHeader( QDateTime dt, HeaderType headerType ) const;
 
+        void drawTimeLine(QPainter* painter, const QRectF& rect);
+
         QDateTime startDateTime;
         QDateTime endDateTime;
         qreal dayWidth;
@@ -150,6 +155,7 @@ namespace KGantt {
         DateTimeScaleFormatter hour_lower;
         DateTimeScaleFormatter minute_upper;
         DateTimeScaleFormatter minute_lower;
+        DateTimeTimeLine *timeLine;
     };
 
     inline DateTimeGrid::DateTimeGrid( DateTimeGrid::Private* d ) : AbstractGrid( d ) {}
