@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "kganttgraphicsitem.h"
@@ -35,15 +35,12 @@
 #include <QPainter>
 #include <QAbstractItemModel>
 #include <QAbstractProxyModel>
-#include <QItemSelectionModel>
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsLineItem>
 
 #include <QDebug>
 
-/*!\class KGantt::GraphicsItem
- * \internal
- */
+
 
 using namespace KGantt;
 
@@ -91,7 +88,7 @@ void GraphicsItem::init()
     setAcceptHoverEvents( true );
     setHandlesChildEvents( true );
     setZValue( 100. );
-    m_dragline = 0;
+    m_dragline = nullptr;
 }
 
 int GraphicsItem::type() const
@@ -133,7 +130,7 @@ StyleOptionGanttItem GraphicsItem::getStyleOption() const
         case StyleOptionGanttItem::Center: opt.displayAlignment = Qt::AlignCenter; break;
         }
     }
-    opt.grid = scene()->grid();
+    opt.grid = const_cast<AbstractGrid*>(scene()->getGrid());
     opt.text = m_index.model()->data( m_index, Qt::DisplayRole ).toString();
     if ( isEnabled() ) opt.state  |= QStyle::State_Enabled;
     if ( isSelected() ) opt.state |= QStyle::State_Selected;
@@ -288,7 +285,7 @@ void GraphicsItem::updateItem( const Span& rowGeometry, const QPersistentModelIn
         return;
     }
 
-    const Span s = scene()->grid()->mapToChart( static_cast<const QModelIndex&>(idx) );
+    const Span s = scene()->getGrid()->mapToChart( static_cast<const QModelIndex&>(idx) );
     setPos( QPointF( s.start(), rowGeometry.start() ) );
     setRect( QRectF( 0., 0., s.length(), rowGeometry.length() ) );
     setIndex( idx );
@@ -328,13 +325,7 @@ QVariant GraphicsItem::itemChange( GraphicsItemChange change, const QVariant& va
     } else if ( change==QGraphicsItem::ItemSelectedChange ) {
         if ( index().isValid() && !( index().model()->flags( index() ) & Qt::ItemIsSelectable ) ) {
             // Reject selection attempt
-            return qVariantFromValue( false );
-        }
-
-        if ( value.toBool() ) {
-            scene()->selectionModel()->select( index(), QItemSelectionModel::Select );
-        } else {
-            scene()->selectionModel()->select( index(), QItemSelectionModel::Deselect );
+            return QVariant::fromValue( false );
         }
     }
 
@@ -344,7 +335,6 @@ QVariant GraphicsItem::itemChange( GraphicsItemChange change, const QVariant& va
 void GraphicsItem::focusInEvent( QFocusEvent* event )
 {
     Q_UNUSED( event );
-    scene()->selectionModel()->select( index(), QItemSelectionModel::SelectCurrent );
 }
 
 void GraphicsItem::updateModel()
@@ -369,7 +359,7 @@ void GraphicsItem::updateModel()
                  it2 != m_endConstraints.end() ;
                  ++it2 )
                 constraints.push_back((*it2)->proxyConstraint());
-            if ( scene()->grid()->mapFromChart( Span( scenePos().x(), rect().width() ),
+            if ( scene()->getGrid()->mapFromChart( Span( scenePos().x(), rect().width() ),
                                                 index(),
                                                 constraints ) ) {
                 scene()->updateRow( index().parent() );
@@ -429,13 +419,16 @@ void GraphicsItem::mousePressEvent( QGraphicsSceneMouseEvent* event )
         m_istate = istate;
         m_presspos = event->pos();
         m_pressscenepos = event->scenePos();
-        scene()->itemPressed( index() );
+
+        scene()->itemPressed( index(), event );
 
         switch ( m_istate ) {
         case ItemDelegate::State_ExtendLeft:
         case ItemDelegate::State_ExtendRight:
         default: /* State_Move */
-            BASE::mousePressEvent( event );
+            if (!(flags() & ItemIsMovable)) {
+                event->ignore();
+            }
             break;
         }
     } else {
@@ -449,7 +442,7 @@ void GraphicsItem::mouseReleaseEvent( QGraphicsSceneMouseEvent* event )
     if ( !m_presspos.isNull() ) {
         scene()->itemClicked( index() );
     }
-    delete m_dragline; m_dragline = 0;
+    delete m_dragline; m_dragline = nullptr;
     if ( scene()->dragSource() ) {
         // Create a new constraint
         GraphicsItem* other = qgraphicsitem_cast<GraphicsItem*>( scene()->itemAt( event->scenePos(), QTransform() ) );
@@ -481,7 +474,7 @@ void GraphicsItem::mouseReleaseEvent( QGraphicsSceneMouseEvent* event )
             }
         }
 
-        scene()->setDragSource( 0 );
+        scene()->setDragSource( nullptr );
         //scene()->update();
     } else {
         if ( isEditable() ) {
@@ -500,7 +493,6 @@ void GraphicsItem::mouseReleaseEvent( QGraphicsSceneMouseEvent* event )
     }
 
     m_presspos = QPointF();
-    BASE::mouseReleaseEvent( event );
 }
 
 void GraphicsItem::mouseDoubleClickEvent( QGraphicsSceneMouseEvent* event )
@@ -566,7 +558,6 @@ void GraphicsItem::mouseMoveEvent( QGraphicsSceneMouseEvent* event )
             break;
         }
 
-        scene()->selectionModel()->setCurrentIndex( index(), QItemSelectionModel::Current );
         updateItemFromMouse(event->scenePos());
         //BASE::mouseMoveEvent(event);
         break;
