@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "kganttgraphicsview.h"
@@ -22,6 +22,7 @@
 #include "kganttabstractrowcontroller.h"
 #include "kganttgraphicsitem.h"
 #include "kganttconstraintmodel.h"
+#include "kganttdatetimetimelinedialog.h"
 
 #include <QMenu>
 #include <QPainter>
@@ -30,6 +31,8 @@
 #include <QScrollBar>
 #include <QAbstractProxyModel>
 #include <QPrinter>
+#include <QItemSelectionModel>
+#include <QGraphicsSceneMouseEvent>
 
 #include <cassert>
 
@@ -37,7 +40,7 @@
 #include "../evaldialog/evaldialog.h"
 #endif
 
-/*!\class KGantt::HeaderWidget
+/*\class KGantt::HeaderWidget
  * \internal
  */
 
@@ -85,14 +88,15 @@ void HeaderWidget::contextMenuEvent( QContextMenuEvent* event )
     QMenu contextMenu;
 
     DateTimeGrid* const grid = qobject_cast< DateTimeGrid* >( view()->grid() );
-    QAction* actionScaleAuto = 0;
-    QAction* actionScaleMonth = 0;
-    QAction* actionScaleWeek = 0;
-    QAction* actionScaleDay = 0;
-    QAction* actionScaleHour = 0;
-    QAction* actionZoomIn = 0;
-    QAction* actionZoomOut = 0;
-    if ( grid != 0 )
+    QAction* actionScaleAuto = nullptr;
+    QAction* actionScaleMonth = nullptr;
+    QAction* actionScaleWeek = nullptr;
+    QAction* actionScaleDay = nullptr;
+    QAction* actionScaleHour = nullptr;
+    QAction* actionZoomIn = nullptr;
+    QAction* actionZoomOut = nullptr;
+    QAction* actionTimeline = nullptr;
+    if ( grid != nullptr )
     {
         QMenu* menuScale = new QMenu( tr( "Scale", "@title:menu" ), &contextMenu );
         QActionGroup* scaleGroup = new QActionGroup( &contextMenu );
@@ -137,6 +141,10 @@ void HeaderWidget::contextMenuEvent( QContextMenuEvent* event )
         contextMenu.addAction( actionZoomIn );
         actionZoomOut = new QAction( tr( "Zoom Out", "@action:inmenu" ), &contextMenu );
         contextMenu.addAction( actionZoomOut );
+
+        contextMenu.addSeparator();
+        actionTimeline = new QAction( tr( "Timeline...", "@action:inmenu" ), &contextMenu );
+        contextMenu.addAction( actionTimeline );
     }
 
     if ( contextMenu.isEmpty() )
@@ -146,49 +154,54 @@ void HeaderWidget::contextMenuEvent( QContextMenuEvent* event )
     }
 
     const QAction* const action = contextMenu.exec( event->globalPos() );
-    if ( action == 0 ) {}
+    if ( action == nullptr ) {}
     else if ( action == actionScaleAuto )
     {
-        assert( grid != 0 );
+        assert( grid != nullptr );
         grid->setScale( DateTimeGrid::ScaleAuto );
     }
     else if ( action == actionScaleMonth )
     {
-        assert( grid != 0 );
+        assert( grid != nullptr );
         grid->setScale( DateTimeGrid::ScaleMonth );
     }
     else if ( action == actionScaleWeek )
     {
-        assert( grid != 0 );
+        assert( grid != nullptr );
         grid->setScale( DateTimeGrid::ScaleWeek );
     }
     else if ( action == actionScaleDay )
     {
-        assert( grid != 0 );
+        assert( grid != nullptr );
         grid->setScale( DateTimeGrid::ScaleDay );
     }
     else if ( action == actionScaleHour )
     {
-        assert( grid != 0 );
+        assert( grid != nullptr );
         grid->setScale( DateTimeGrid::ScaleHour );
     }
     else if ( action == actionZoomIn )
     {
-        assert( grid != 0 );
+        assert( grid != nullptr );
         grid->setDayWidth( grid->dayWidth() * 1.25 );
     }
     else if ( action == actionZoomOut )
     {
-        assert( grid != 0 );
+        assert( grid != nullptr );
         // daywidth *MUST NOT* go below 1.0, it is used as an integer later on
         grid->setDayWidth( qMax<qreal>( 1.0, grid->dayWidth() * 0.8 ) );
     }
-
+    else if ( action == actionTimeline )
+    {
+        assert( grid != nullptr );
+        DateTimeTimeLineDialog dlg(grid->timeLine());
+        dlg.exec();
+    }
     event->accept();
 }
 
 GraphicsView::Private::Private( GraphicsView* _q )
-  : q( _q ), rowcontroller(0), headerwidget( _q )
+  : q( _q ), rowcontroller(nullptr), headerwidget( _q )
 {
 }
 
@@ -310,7 +323,7 @@ void GraphicsView::Private::slotItemClicked( const QModelIndex& idx )
 {
     QModelIndex sidx = idx;//scene.summaryHandlingModel()->mapToSource( idx );
     emit q->clicked( sidx );
-    if (q->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, q))
+    if (q->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, nullptr, q))
         emit q->activated( sidx );
 }
 
@@ -318,7 +331,7 @@ void GraphicsView::Private::slotItemDoubleClicked( const QModelIndex& idx )
 {
     QModelIndex sidx = idx;//scene.summaryHandlingModel()->mapToSource( idx );
     emit q->qrealClicked( sidx );
-    if (!q->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, q))
+    if (!q->style()->styleHint(QStyle::SH_ItemView_ActivateItemOnSingleClick, nullptr, q))
         emit q->activated( sidx );
 }
 
@@ -327,27 +340,6 @@ void GraphicsView::Private::slotHeaderContextMenuRequested( const QPoint& pt )
     emit q->headerContextMenuRequested( headerwidget.mapToGlobal( pt ) );
 }
 
-/*!\class KGantt::GraphicsView kganttgraphicsview.h KGanttGraphicsView
- * \ingroup KGantt
- * \brief The GraphicsView class provides a model/view implementation of a gantt chart.
- *
- *
- */
-
-/*! \fn void GraphicsView::activated( const QModelIndex & index ) */
-/*! \fn void GraphicsView::clicked( const QModelIndex & index ); */
-/*! \fn void GraphicsView::qrealClicked( const QModelIndex & index ); */
-/*! \fn void GraphicsView::entered( const QModelIndex & index ); */
-/*! \fn void GraphicsView::pressed( const QModelIndex & index ); */
-/*! \fn void GraphicsView::headerContextMenuRequested( const QPoint& pt )
- * This signal is emitted when the header has contextMenuPolicy Qt::CustomContextMenu
- * and the widget wants to show a context menu for the header. Unlike in
- * QWidget::customContextMenuRequested() signal, \a pt is here in global coordinates.
- */
-
-/*! Constructor. Creates a new KGantt::GraphicsView with parent
- * \a parent.
- */
 GraphicsView::GraphicsView( QWidget* parent )
     : QGraphicsView( parent ), _d( new Private( this ) )
 {
@@ -355,22 +347,22 @@ GraphicsView::GraphicsView( QWidget* parent )
 #if defined KDAB_EVAL
   EvalDialog::checkEvalLicense( "KD Gantt" );
 #endif
-    connect( horizontalScrollBar(), SIGNAL( valueChanged( int ) ),
-             this, SLOT( slotHorizontalScrollValueChanged( int ) ) );
-    connect( &_d->scene, SIGNAL( gridChanged() ),
-             this, SLOT( slotGridChanged() ) );
-    connect( &_d->scene, SIGNAL( entered( const QModelIndex& ) ),
-             this, SIGNAL( entered( const QModelIndex& ) ) );
-    connect( &_d->scene, SIGNAL( pressed( const QModelIndex& ) ),
-             this, SIGNAL( pressed( const QModelIndex& ) ) );
-    connect( &_d->scene, SIGNAL( clicked( const QModelIndex& ) ),
-             this, SLOT( slotItemClicked( const QModelIndex& ) ) );
-    connect( &_d->scene, SIGNAL( qrealClicked( const QModelIndex& ) ),
-             this, SLOT( slotItemDoubleClicked( const QModelIndex& ) ) );
-    connect( &_d->scene, SIGNAL( sceneRectChanged( const QRectF& ) ),
-             this, SLOT( updateSceneRect() ) );
-    connect( &_d->headerwidget, SIGNAL( customContextMenuRequested( const QPoint& ) ),
-             this, SLOT( slotHeaderContextMenuRequested( const QPoint& ) ) );
+    connect( horizontalScrollBar(), SIGNAL(valueChanged(int)),
+             this, SLOT(slotHorizontalScrollValueChanged(int)) );
+    connect( &_d->scene, SIGNAL(gridChanged()),
+             this, SLOT(slotGridChanged()) );
+    connect( &_d->scene, SIGNAL(entered(QModelIndex)),
+             this, SIGNAL(entered(QModelIndex)) );
+    connect( &_d->scene, SIGNAL(pressed(QModelIndex)),
+             this, SIGNAL(pressed(QModelIndex)) );
+    connect( &_d->scene, SIGNAL(clicked(QModelIndex)),
+             this, SLOT(slotItemClicked(QModelIndex)) );
+    connect( &_d->scene, SIGNAL(qrealClicked(QModelIndex)),
+             this, SLOT(slotItemDoubleClicked(QModelIndex)) );
+    connect( &_d->scene, SIGNAL(sceneRectChanged(QRectF)),
+             this, SLOT(updateSceneRect()) );
+    connect( &_d->headerwidget, SIGNAL(customContextMenuRequested(QPoint)),
+             this, SLOT(slotHeaderContextMenuRequested(QPoint)) );
     setScene( &_d->scene );
 
     // HACK!
@@ -383,7 +375,7 @@ GraphicsView::GraphicsView( QWidget* parent )
     //setCacheMode( CacheBackground );
 }
 
-/*! Destroys this view. */
+
 GraphicsView::~GraphicsView()
 {
     delete _d;
@@ -391,23 +383,7 @@ GraphicsView::~GraphicsView()
 
 #define d d_func()
 
-/*! Sets the model to be displayed in this view to
- * \a model. The view does not take ownership of the model.
- *
- * To make a model work well with GraphicsView it must
- * have a certain layout. Whether the model is flat or has a
- * treestrucure is not important, as long as an
- * AbstractRowController is provided that can navigate the
- * model.
- *
- * GraphicsView operates per row in the model. The data is always
- * taken from the _last_ item in the row. The ItemRoles used are
- * Qt::DisplayRole and the roles defined in KGantt::ItemDataRole.
- * 
- * Note: This model is not returned by \a model()
- * 
- * \see GraphicsView::model
- */
+
 void GraphicsView::setModel( QAbstractItemModel* model )
 {
     if ( d->scene.model() ) {
@@ -415,17 +391,14 @@ void GraphicsView::setModel( QAbstractItemModel* model )
     }
 
     d->scene.setModel( model );
-    connect( model, SIGNAL( dataChanged( const QModelIndex&, const QModelIndex& ) ),
-             this, SLOT( updateSceneRect() ) );
+    if (model) {
+        connect( model, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
+                this, SLOT(updateSceneRect()) );
+    }
     updateScene();
 }
 
-/*! \returns the current model displayed by this view
- * 
- * Note: The returned model is not the model set with \a setModel()
- * 
- * \see GraphicsView::setModel
- */
+
 QAbstractItemModel* GraphicsView::model() const
 {
     return d->scene.model();
@@ -439,98 +412,81 @@ void GraphicsView::setSummaryHandlingModel( QAbstractProxyModel* proxyModel )
     /* Connections. We have to rely on the treeview
      * to receive the signals before we do(!)
      */
-    connect( proxyModel, SIGNAL( columnsInserted( const QModelIndex&, int, int ) ),
-             this,  SLOT( slotColumnsInserted( const QModelIndex&,  int, int ) ) );
-    connect( proxyModel, SIGNAL( columnsRemoved( const QModelIndex&, int, int ) ),
-             this,  SLOT( slotColumnsRemoved( const QModelIndex&,  int, int ) ) );
-    connect( proxyModel, SIGNAL( dataChanged( const QModelIndex&, const QModelIndex& ) ),
-             this,  SLOT( slotDataChanged( const QModelIndex&, const QModelIndex& ) ) );
-    connect( proxyModel, SIGNAL( layoutChanged() ),
-             this,  SLOT( slotLayoutChanged() ) );
-    connect( proxyModel, SIGNAL( modelReset() ),
-             this,  SLOT( slotModelReset() ) );
-    connect( proxyModel, SIGNAL( rowsInserted( const QModelIndex&, int, int ) ),
-             this,  SLOT( slotRowsInserted( const QModelIndex&,  int, int ) ) );
-    connect( proxyModel, SIGNAL( rowsAboutToBeRemoved( const QModelIndex&, int, int ) ),
-             this,  SLOT( slotRowsAboutToBeRemoved( const QModelIndex&,  int, int ) ) );
-    connect( proxyModel, SIGNAL( rowsRemoved( const QModelIndex&, int, int ) ),
-             this,  SLOT( slotRowsRemoved( const QModelIndex&,  int, int ) ) );
+    connect( proxyModel, SIGNAL(columnsInserted(QModelIndex,int,int)),
+             this,  SLOT(slotColumnsInserted(QModelIndex,int,int)) );
+    connect( proxyModel, SIGNAL(columnsRemoved(QModelIndex,int,int)),
+             this,  SLOT(slotColumnsRemoved(QModelIndex,int,int)) );
+    connect( proxyModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
+             this,  SLOT(slotDataChanged(QModelIndex,QModelIndex)) );
+    connect( proxyModel, SIGNAL(layoutChanged()),
+             this,  SLOT(slotLayoutChanged()) );
+    connect( proxyModel, SIGNAL(modelReset()),
+             this,  SLOT(slotModelReset()) );
+    connect( proxyModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
+             this,  SLOT(slotRowsInserted(QModelIndex,int,int)) );
+    connect( proxyModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
+             this,  SLOT(slotRowsAboutToBeRemoved(QModelIndex,int,int)) );
+    connect( proxyModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
+             this,  SLOT(slotRowsRemoved(QModelIndex,int,int)) );
 
     updateScene();
 }
 
-/*! Sets the constraintmodel displayed by this view.
- * \see KGantt::ConstraintModel.
- */
+
 void GraphicsView::setConstraintModel( ConstraintModel* cmodel )
 {
     d->scene.setConstraintModel( cmodel );
 }
 
-/*! \returns the KGantt::ConstraintModel displayed by this view.
- */
+
 ConstraintModel* GraphicsView::constraintModel() const
 {
     return d->scene.constraintModel();
 }
 
-/*! \returns the KGantt::SummaryHandlingProxyModel used by this view.
- */
+
 QAbstractProxyModel* GraphicsView::summaryHandlingModel() const
 {
     return d->scene.summaryHandlingModel();
 }
 
-/*! Sets the root index of the model displayed by this view.
- * Similar to QAbstractItemView::setRootIndex, default is QModelIndex().
- */
+
 void GraphicsView::setRootIndex( const QModelIndex& idx )
 {
     d->scene.setRootIndex( idx );
 }
 
-/*! \returns the rootindex for this view.
- */
+
 QModelIndex GraphicsView::rootIndex() const
 {
     return d->scene.rootIndex();
 }
 
-/*! Sets the QItemSelectionModel used by this view to manage
- * selections. Similar to QAbstractItemView::setSelectionModel
- */
+
 void GraphicsView::setSelectionModel( QItemSelectionModel* model )
 {
     d->scene.setSelectionModel( model );
 }
 
-/*! \returns the QItemSelectionModel used by this view
- */
+
 QItemSelectionModel* GraphicsView::selectionModel() const
 {
     return d->scene.selectionModel();
 }
 
-/*! Sets the KGantt::ItemDelegate used for rendering items on this
- * view. \see ItemDelegate and QAbstractItemDelegate.
- */
+
 void GraphicsView::setItemDelegate( ItemDelegate* delegate )
 {
     d->scene.setItemDelegate( delegate );
 }
 
-/*! \returns the ItemDelegate used by this view to render items
-*/
+
 ItemDelegate* GraphicsView::itemDelegate() const
 {
     return d->scene.itemDelegate();
 }
 
-/*! Sets the AbstractRowController used by this view. The
- * AbstractRowController deals with the height and position
- * of each row and with which parts of the model are
- * displayed. \see AbstractRowController
- */
+
 void GraphicsView::setRowController( AbstractRowController* rowcontroller )
 {
     d->rowcontroller = rowcontroller;
@@ -538,76 +494,60 @@ void GraphicsView::setRowController( AbstractRowController* rowcontroller )
     updateScene();
 }
 
-/*! \returns the AbstractRowController
- * for this view. \see setRowController
- */
+
 AbstractRowController* GraphicsView::rowController() const
 {
     return d->rowcontroller;
 }
 
-/*! Sets the AbstractGrid for this view. The grid is an
- * object that controls how QModelIndexes are mapped
- * to and from the view and how the background and header
- * is rendered. \see AbstractGrid and DateTimeGrid.
- */
+
 void GraphicsView::setGrid( AbstractGrid* grid )
 {
     d->scene.setGrid( grid );
     d->slotGridChanged();
 }
 
-/*! \returns the AbstractGrid used by this view.
- */
+
 AbstractGrid* GraphicsView::grid() const
 {
     return d->scene.grid();
 }
 
-/*! Sets the view to read-only mode if \a to is true. The default is
- * read/write if the model permits it.
- */
+
+AbstractGrid* GraphicsView::takeGrid()
+{
+    AbstractGrid *grid = d->scene.grid();
+    if ( grid ) {
+        d->scene.setGrid( nullptr) ;
+    }
+    return grid;
+}
+
+
 void GraphicsView::setReadOnly( bool ro )
 {
     d->scene.setReadOnly( ro );
 }
 
-/*!\returns true iff the view is in read-only mode
- */
+
 bool GraphicsView::isReadOnly() const
 {
     return d->scene.isReadOnly();
 }
 
-/*! Sets the context menu policy for the header. The default value
- * Qt::DefaultContextMenu results in a standard context menu on the header
- * that allows the user to set the scale and zoom.
- *
- * Setting this to Qt::CustomContextMenu will cause the signal
- * headerContextMenuRequested(const QPoint& pt) to be emitted instead.
- *
- * \see QWidget::setContextMenuPolicy( Qt::ContextMenuPolicy )
- */
+
 void GraphicsView::setHeaderContextMenuPolicy( Qt::ContextMenuPolicy p )
 {
     d->headerwidget.setContextMenuPolicy( p );
 }
 
-/*! \returns the context menu policy for the header
- */
+
 Qt::ContextMenuPolicy GraphicsView::headerContextMenuPolicy() const
 {
     return d->headerwidget.contextMenuPolicy();
 }
 
-/*! Adds a constraint from \a from to \a to. \a modifiers are the
- * keyboard modifiers pressed by the user when the action is invoked.
- *
- * Override this to control how contraints are added. The default
- * implementation adds a soft constraint unless the Shift key is pressed,
- * in that case it adds a hard constraint. If a constraint is already
- * present, it is removed and nothing is added.
- */
+
 void GraphicsView::addConstraint( const QModelIndex& from,
                                   const QModelIndex& to,
                                   Qt::KeyboardModifiers modifiers )
@@ -646,12 +586,7 @@ void GraphicsView::resizeEvent( QResizeEvent* ev )
     QGraphicsView::resizeEvent( ev );
 }
 
-/*!\returns The QModelIndex for the item located at
- * position \a pos in the view or an invalid index
- * if no item was present at that position.
- *
- * This is useful for for example contextmenus.
- */
+
 QModelIndex GraphicsView::indexAt( const QPoint& pos ) const
 {
     QGraphicsItem* item = itemAt( pos );
@@ -662,21 +597,19 @@ QModelIndex GraphicsView::indexAt( const QPoint& pos ) const
     }
 }
 
-/*! \internal */
+
 void GraphicsView::clearItems()
 {
     d->scene.clearItems();
 }
 
-/*! \internal */
+
 void GraphicsView::updateRow( const QModelIndex& idx )
 {
     d->scene.updateRow( d->scene.summaryHandlingModel()->mapFromSource( idx ) );
 }
 
-/*! \internal
- * Adjusts the bounding rectangle of the scene.
- */
+
 void GraphicsView::updateSceneRect()
 {
     /* What to do with this? We need to shrink the view to
@@ -704,9 +637,7 @@ void GraphicsView::updateSceneRect()
     d->scene.invalidate( QRectF(), QGraphicsScene::BackgroundLayer );
 }
 
-/*! \internal
- * Resets the state of the view.
- */
+
 void GraphicsView::updateScene()
 {
     clearItems();
@@ -722,69 +653,41 @@ void GraphicsView::updateScene()
     if ( scene() ) scene()->invalidate( QRectF(), QGraphicsScene::BackgroundLayer );
 }
 
-/*! \internal */
+#if 0
+TODO: For 3.0
+
 GraphicsItem* GraphicsView::createItem( ItemType type ) const
 {
-    return d->scene.createItem( type );
+    Q_UNUSED(type)
+    return new GraphicsItem;
 }
+#endif
+
 
-/*! \internal */
 void GraphicsView::deleteSubtree( const QModelIndex& idx )
 {
     d->scene.deleteSubtree( d->scene.summaryHandlingModel()->mapFromSource( idx ) );
 }
 
-/*! Print the Gantt chart using \a printer. If \a drawRowLabels
- * is true (the default), each row will have it's label printed
- * on the left side. If \a drawColumnLabels is true (the
- * default), each column will have it's label printed at the
- * top side.
- *
- * This version of print() will print multiple pages.
- */
+
 void GraphicsView::print( QPrinter* printer, bool drawRowLabels, bool drawColumnLabels )
 {
     d->scene.print( printer, drawRowLabels, drawColumnLabels );
 }
 
-/*! Print part of the Gantt chart from \a start to \a end using \a printer.
- * If \a drawRowLabels is true (the default), each row will have it's
- * label printed on the left side. If \a drawColumnLabels is true (the
- * default), each column will have it's label printed at the
- * top side.
- *
- * This version of print() will print multiple pages.
- *
- * To print a certain range of a chart with a DateTimeGrid, use
- * qreal DateTimeGrid::mapFromDateTime( const QDateTime& dt) const
- * to figure out the values for \a start and \a end.
- */
+
 void GraphicsView::print( QPrinter* printer,  qreal start, qreal end, bool drawRowLabels, bool drawColumnLabels )
 {
     d->scene.print( printer, start, end, drawRowLabels, drawColumnLabels );
 }
 
-/*! Render the GanttView inside the rectangle \a target using the painter \a painter.
- * If \a drawRowLabels is true (the default), each row will have it's
- * label printed on the left side. If \a drawColumnLabels is true (the
- * default), each column will have it's label printed at the
- * top side.
- */
+
 void GraphicsView::print( QPainter* painter, const QRectF& targetRect, bool drawRowLabels, bool drawColumnLabels )
 {
   d->scene.print(painter, targetRect, drawRowLabels, drawColumnLabels);
 }
 
-/*! Render the GanttView inside the rectangle \a target using the painter \a painter.
- * If \a drawRowLabels is true (the default), each row will have it's
- * label printed on the left side. If \a drawColumnLabels is true (the
- * default), each column will have it's label printed at the
- * top side.
- *
- * To print a certain range of a chart with a DateTimeGrid, use
- * qreal DateTimeGrid::mapFromDateTime( const QDateTime& dt) const
- * to figure out the values for \a start and \a end.
- */
+
 void GraphicsView::print( QPainter* painter, qreal start, qreal end,
                           const QRectF& targetRect, bool drawRowLabels, bool drawColumnLabels )
 {
